@@ -1,8 +1,7 @@
 ########################################################################
 #                                                                      #
 #              This file is part of the ksh 93u+m package              #
-#             Copyright (c) 2021 Contributors to ksh 93u+m             #
-#                    <https://github.com/ksh93/ksh>                    #
+#          Copyright (c) 2021-2024 Contributors to ksh 93u+m           #
 #                      and is licensed under the                       #
 #                 Eclipse Public License, Version 2.0                  #
 #                                                                      #
@@ -18,16 +17,23 @@
 # compiling older AST code (with Mamfiles containing proto commands) using the
 # current INIT system. This stub ignores all options, then invokes 'cat'.
 
+usage()
+{
+	echo 'Usage: proto [-dfhinprstvzP+S] [-C directory] [-e package] [-l file]'
+	echo '             [-o "name='\''value'\'' ..."] [-L file] file ...'
+	exit 2
+} >&2
+
 while	getopts ':dfhinprstvzPSC:e:l:o:L:' opt
 do	case $opt in
+	:)	usage
+		;;
 	\?)	case $OPTARG in
 		+)	;;
-		*)	echo "proto: $OPTARG: unknown option"
-			echo 'Usage: proto [-dfhinprstvzP+S] [-C directory] [-e package] [-l file]'
-			echo '             [-o "name='\''value'\'' ..."] [-L file] file ...'
-			exit 2
+		*)	echo "proto: $OPTARG: unknown option" >&2
+			usage
 			;;
-		esac >&2
+		esac
 		;;
 	esac
 done
