@@ -7,7 +7,7 @@
 
 SHOPT ACCT=0				# accounting
 SHOPT ACCTFILE=0			# per-user accounting info
-SHOPT ALL_LIBCMD=0			# enable all available builtins in src/lib/libcmd (excludes vmstate if vmalloc isn't enabled)
+SHOPT ALL_LIBCMD=0			# enable all available builtins in src/lib/libcmd
 SHOPT AUDIT=1				# enable auditing per SHOPT_AUDITFILE
 SHOPT AUDITFILE='"/etc/ksh_audit"'	# auditing file
 SHOPT BGX=1				# one SIGCHLD trap per completed job
@@ -16,7 +16,7 @@ SHOPT CMDLIB_HDR=  # '<cmdlist.h>'	# custom -lcmd list for path-bound builtins
 SHOPT CMDLIB_DIR=  # '"/opt/ast/bin"'	# virtual directory prefix for path-bound builtins
 SHOPT CRNL=				# accept MS Windows newlines (<cr><nl>) for <nl>
 SHOPT DEVFD=				# use /dev/fd instead of FIFOs for process substitutions
-SHOPT DYNAMIC=0				# dynamic loading for builtins
+SHOPT DYNAMIC=1				# dynamic loading for builtins
 SHOPT ECHOPRINT=			# make echo equivalent to print
 SHOPT EDPREDICT=0			# History pattern search menu (type #<pattern>, then ESC <number> TAB). Experimental.
 SHOPT ESH=1				# emacs/gmacs edit mode
@@ -29,9 +29,9 @@ SHOPT MKSERVICE=0			# enable the mkservice and eloop builtins
 SHOPT MULTIBYTE=			# multibyte character handling
 SHOPT NAMESPACE=1			# allow namespaces
 SHOPT NOECHOE=0				# turn off 'echo -e' when SHOPT_ECHOPRINT is disabled
-SHOPT OLDTERMIO=			# support both TCGETA and TCGETS
 SHOPT OPTIMIZE=1			# optimize loop invariants
 SHOPT P_SUID=0				# real UIDs >= this value require -p for set[ug]id (to turn off, use empty, not 0)
+SHOPT PRINTF_LEGACY=			# allow noncompliant printf(1) syntax (format arg starting with '-' without prior '--')
 SHOPT REGRESS=				# enable __regress__ builtin and instrumented intercepts for testing
 SHOPT REMOTE=				# enable --rc if running as a remote shell
 SHOPT SCRIPTONLY=0			# build ksh for running scripts only; compile out the interactive shell
