@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1982-2011 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2022 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -18,7 +18,6 @@
 
 #include	"shopt.h"
 #include	<ast.h>
-#include	"FEATURE/options"
 #include	"lexstates.h"
 
 /* The ST_* state table names are defined in include/lexstates.h */
@@ -29,32 +28,60 @@
  */
 static const char sh_lexstate0[256] =
 {
+  /*	nul	soh	stx	etx	eot	enq	ack	bel	*/
 	S_EOF,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,
+
+  /*	bs	ht/tab	nl/lf	vt	ff	cr	so	si	*/
 #if SHOPT_CRNL
 	S_REG,	0,	S_NLTOK,S_REG,	S_REG,	0,	S_REG,	S_REG,
 #else
 	S_REG,	0,	S_NLTOK,S_REG,	S_REG,	S_REG,	S_REG,	S_REG,
 #endif /* SHOPT_CRNL */
-	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,
+
+  /*	dle	dc1	dc2	dc3	dc4	nak	syn	etb	*/
 	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,
 
-	0,	S_REG,	S_REG,	S_COM,	S_REG,	S_REG,	S_OP,	S_REG,
-	S_OP,	S_OP,	S_REG,	S_REG,	S_REG,	S_REG,	S_NAME,	S_REG,
+  /*	can	em	sub	esc	fs	gs	rs	us	*/
 	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,
+
+  /*	space	!	"	#	$	%	&	'	*/
+	0,	S_REG,	S_REG,	S_COM,	S_REG,	S_REG,	S_OP,	S_REG,
+
+  /*	(	)	*	+	,	-	.	/	*/
+	S_OP,	S_OP,	S_REG,	S_REG,	S_REG,	S_REG,	S_NAME,	S_REG,
+
+  /*	0	1	2	3	4	5	6	7	*/
+	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,
+
+  /*	8	9	:	;	<	=	>	?	*/
 	S_REG,	S_REG,	S_REG,	S_OP,	S_OP,	S_REG,	S_OP,	S_REG,
 
+  /*	@	A	B	C	D	E	F	G	*/
 	S_REG,	S_NAME,	S_NAME,	S_NAME,	S_NAME,	S_NAME,	S_NAME,	S_NAME,
+
+  /*	H	I	J	K	L	M	N	O	*/
 	S_NAME,	S_NAME,	S_NAME,	S_NAME,	S_NAME,	S_NAME,	S_NAME,	S_NAME,
+
+  /*	P	Q	R	S	T	U	V	W	*/
 	S_NAME,	S_NAME,	S_NAME,	S_NAME,	S_NAME,	S_NAME,	S_NAME,	S_NAME,
+
+  /*	X	Y	Z	[	\	]	^	_	*/
 	S_NAME,	S_NAME,	S_NAME,	S_REG,	S_REG,	S_REG,	S_REG,	S_NAME,
 
+  /*	`	a	b	c	d	e	f	g	*/
 	S_REG,	S_NAME,	S_NAME,	S_RES,	S_RES,	S_RES,	S_RES,	S_NAME,
+
+  /*	h	i	j	k	l	m	n	o	*/
 #if SHOPT_NAMESPACE
 	S_NAME,	S_RES,	S_NAME,	S_NAME,	S_NAME,	S_NAME,	S_RES,	S_NAME,
 #else
 	S_NAME,	S_RES,	S_NAME,	S_NAME,	S_NAME,	S_NAME,	S_NAME,	S_NAME,
 #endif /* SHOPT_NAMESPACE */
+
+  /*	p	q	r	s	t	u	v	w	*/
 	S_NAME,	S_NAME,	S_NAME,	S_RES,	S_RES,	S_RES,	S_NAME,	S_RES,
+
+  /*	x	y	z	{	|	}	~	del	*/
 	S_NAME,	S_NAME,	S_NAME,	S_BRACE,S_OP,	S_BRACE,S_TILDE,S_REG,
 
 	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,
@@ -81,28 +108,56 @@ static const char sh_lexstate0[256] =
  */
 static const char sh_lexstate1[256] =
 {
+  /*	nul	soh	stx	etx	eot	enq	ack	bel	*/
 	S_EOF,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,
+
+  /*	bs	ht/tab	nl/lf	vt	ff	cr	so	si	*/
 #if SHOPT_CRNL
 	S_REG,	S_BREAK,S_BREAK,S_REG,	S_REG,	S_BREAK,S_REG,	S_REG,
 #else
 	S_REG,	S_BREAK,S_BREAK,S_REG,	S_REG,	S_REG,	S_REG,	S_REG,
 #endif /* SHOPT_CRNL */
-	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,
+
+  /*	dle	dc1	dc2	dc3	dc4	nak	syn	etb	*/
 	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,
 
+  /*	can	em	sub	esc	fs	gs	rs	us	*/
+	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,
+
+  /*	space	!	"	#	$	%	&	'	*/
 	S_BREAK,S_EPAT,	S_QUOTE,S_REG,	S_DOL,	S_EPAT,	S_BREAK,S_LIT,
-	S_BREAK,S_BREAK,S_PAT,	S_EPAT,	S_REG,	S_EPAT,	S_DOT,	S_REG,
-	0,	0,	0,	0,	0,	0,	0,	0,
-	0,	0,	S_LABEL,S_BREAK,S_BREAK,S_EQ,	S_BREAK,S_PAT,
 
+  /*	(	)	*	+	,	-	.	/	*/
+	S_BREAK,S_BREAK,S_PAT,	S_EPAT,	S_REG,	S_EPAT,	S_DOT,	S_REG,
+
+  /*	0	1	2	3	4	5	6	7	*/
+	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	8	9	:	;	<	=	>	?	*/
+	0,	0,	S_REG,	S_BREAK,S_BREAK,S_EQ,	S_BREAK,S_PAT,
+
+  /*	@	A	B	C	D	E	F	G	*/
 	S_EPAT,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	H	I	J	K	L	M	N	O	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	P	Q	R	S	T	U	V	W	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	X	Y	Z	[	\	]	^	_	*/
 	0,	0,	0,	S_BRACT,S_ESC,	S_REG,	S_REG,	0,
 
+  /*	`	a	b	c	d	e	f	g	*/
 	S_GRAVE,0,	0,	0,	0,	0,	0,	0,
+
+  /*	h	i	j	k	l	m	n	o	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	p	q	r	s	t	u	v	w	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	x	y	z	{	|	}	~	del	*/
 	0,	0,	0,	S_BRACE,S_BREAK,S_BRACE,S_EPAT,	S_REG,
 
 	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,	S_REG,
@@ -128,28 +183,56 @@ static const char sh_lexstate1[256] =
  */
 static const char sh_lexstate2[256] =
 {
+  /*	nul	soh	stx	etx	eot	enq	ack	bel	*/
 	S_EOF,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	bs	ht/tab	nl/lf	vt	ff	cr	so	si	*/
 #if SHOPT_CRNL
 	0,	S_BREAK,S_BREAK,0,	0,	S_BREAK,0,	0,
 #else
 	0,	S_BREAK,S_BREAK,0,	0,	0,	0,	0,
 #endif /* SHOPT_CRNL */
-	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	dle	dc1	dc2	dc3	dc4	nak	syn	etb	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
 
-	S_BREAK,S_EPAT,	S_QUOTE,0,	S_DOL,	S_EPAT,	S_BREAK,S_LIT,
-	S_BREAK,S_BREAK,S_PAT,	S_EPAT,	0,	S_EPAT,	0,	0,
+  /*	can	em	sub	esc	fs	gs	rs	us	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	space	!	"	#	$	%	&	'	*/
+	S_BREAK,S_EPAT,	S_QUOTE,0,	S_DOL,	S_EPAT,	S_BREAK,S_LIT,
+
+  /*	(	)	*	+	,	-	.	/	*/
+	S_BREAK,S_BREAK,S_PAT,	S_EPAT,	0,	S_EPAT,	0,	0,
+
+  /*	0	1	2	3	4	5	6	7	*/
+	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	8	9	:	;	<	=	>	?	*/
 	0,	0,	S_COLON,S_BREAK,S_BREAK,0,	S_BREAK,S_PAT,
 
+  /*	@	A	B	C	D	E	F	G	*/
 	S_EPAT,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	H	I	J	K	L	M	N	O	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	P	Q	R	S	T	U	V	W	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	X	Y	Z	[	\	]	^	_	*/
 	0,	0,	0,	S_PAT,	S_ESC,	0,	0,	0,
 
+  /*	`	a	b	c	d	e	f	g	*/
 	S_GRAVE,0,	0,	0,	0,	0,	0,	0,
+
+  /*	h	i	j	k	l	m	n	o	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	p	q	r	s	t	u	v	w	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	x	y	z	{	|	}	~	del	*/
 	0,	0,	0,	S_BRACE,S_BREAK,S_BRACE,S_EPAT,	0,
 };
 
@@ -159,19 +242,40 @@ static const char sh_lexstate2[256] =
  */
 static const char sh_lexstate3[256] =
 {
+  /*	nul	soh	stx	etx	eot	enq	ack	bel	*/
 	S_EOF,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	bs	ht/tab	nl/lf	vt	ff	cr	so	si	*/
 	0,	0,	S_NL,	0,	0,	0,	0,	0,
-	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	dle	dc1	dc2	dc3	dc4	nak	syn	etb	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
 
+  /*	can	em	sub	esc	fs	gs	rs	us	*/
+	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	space	!	"	#	$	%	&	'	*/
 	0,	0,	0,	0,	0,	0,	0,	S_LIT,
-	0,	0,	0,	0,	0,	0,	0,	0,
-	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	(	)	*	+	,	-	.	/	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
 
+  /*	0	1	2	3	4	5	6	7	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	8	9	:	;	<	=	>	?	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	@	A	B	C	D	E	F	G	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	H	I	J	K	L	M	N	O	*/
+	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	P	Q	R	S	T	U	V	W	*/
+	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	X	Y	Z	[	\	]	^	_	*/
 	0,	0,	0,	0,	S_ESC2,	0,	0,	0
 };
 
@@ -181,21 +285,52 @@ static const char sh_lexstate3[256] =
  */
 static const char sh_lexstate4[256] =
 {
+  /*	nul	soh	stx	etx	eot	enq	ack	bel	*/
 	S_EOF,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	bs	ht/tab	nl/lf	vt	ff	cr	so	si	*/
 	0,	0,	S_NL,	0,	0,	0,	0,	0,
+
+  /*	dle	dc1	dc2	dc3	dc4	nak	syn	etb	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	can	em	sub	esc	fs	gs	rs	us	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	space	!	"	#	$	%	&	'	*/
 	0,	0,	S_QUOTE,0,	S_DOL,	0,	0,	0,
+
+  /*	(	)	*	+	,	-	.	/	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	0	1	2	3	4	5	6	7	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	8	9	:	;	<	=	>	?	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	@	A	B	C	D	E	F	G	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	H	I	J	K	L	M	N	O	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	P	Q	R	S	T	U	V	W	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	X	Y	Z	[	\	]	^	_	*/
 	0,	0,	0,	0,	S_ESC,	0,	0,	0,
+
+  /*	`	a	b	c	d	e	f	g	*/
 	S_GRAVE,0,	0,	0,	0,	0,	0,	0,
+
+  /*	h	i	j	k	l	m	n	o	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	p	q	r	s	t	u	v	w	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	x	y	z	{	|	}	~	del	*/
 	0,	0,	0,	0,	0,	S_RBRA,	0,	0
 };
 
@@ -205,21 +340,52 @@ static const char sh_lexstate4[256] =
  */
 static const char sh_lexstate5[256] =
 {
+  /*	nul	soh	stx	etx	eot	enq	ack	bel	*/
 	S_EOF,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	bs	ht/tab	nl/lf	vt	ff	cr	so	si	*/
 	0,	S_BLNK,	S_NL,	0,	0,	0,	0,	0,
+
+  /*	dle	dc1	dc2	dc3	dc4	nak	syn	etb	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	can	em	sub	esc	fs	gs	rs	us	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	space	!	"	#	$	%	&	'	*/
 	S_BLNK,	0,	S_QUOTE,0,	S_DOL,	0,	S_META,	S_LIT,
+
+  /*	(	)	*	+	,	-	.	/	*/
 	S_PUSH,	S_POP,	0,	0,	0,	0,	0,	0,
+
+  /*	0	1	2	3	4	5	6	7	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	8	9	:	;	<	=	>	?	*/
 	0,	0,	0,	S_POP,	S_META,	0,	S_META,	0,
+
+  /*	@	A	B	C	D	E	F	G	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	H	I	J	K	L	M	N	O	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	P	Q	R	S	T	U	V	W	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	X	Y	Z	[	\	]	^	_	*/
 	0,	0,	0,	S_BRACT,S_ESC,	S_POP,	0,	0,
+
+  /*	`	a	b	c	d	e	f	g	*/
 	S_GRAVE,0,	0,	0,	0,	0,	0,	0,
+
+  /*	h	i	j	k	l	m	n	o	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	p	q	r	s	t	u	v	w	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	x	y	z	{	|	}	~	del	*/
 	0,	0,	0,	S_BRACE,S_META,	S_POP,	S_TILDE,0
 };
 
@@ -229,24 +395,52 @@ static const char sh_lexstate5[256] =
  */
 static const char sh_lexstate6[256] =
 {
+  /*	nul	soh	stx	etx	eot	enq	ack	bel	*/
 	S_EOF,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,
-	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,
-	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,
+
+  /*	bs	ht/tab	nl/lf	vt	ff	cr	so	si	*/
 	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,
 
+  /*	dle	dc1	dc2	dc3	dc4	nak	syn	etb	*/
+	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,
+
+  /*	can	em	sub	esc	fs	gs	rs	us	*/
+	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,
+
+  /*	space	!	"	#	$	%	&	'	*/
 	S_ERR,	S_SPC1,	S_ERR,	S_SPC1,	S_SPC2,	S_ERR,	S_ERR,	S_LIT,
+
+  /*	(	)	*	+	,	-	.	/	*/
 	S_PAR,	S_ERR,	S_SPC2,	S_ERR,	S_ERR,	S_SPC2,	S_ALP,	S_ERR,
+
+  /*	0	1	2	3	4	5	6	7	*/
 	S_DIG,	S_DIG,	S_DIG,	S_DIG,	S_DIG,	S_DIG,	S_DIG,	S_DIG,
+
+  /*	8	9	:	;	<	=	>	?	*/
 	S_DIG,	S_DIG,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_SPC2,
 
+  /*	@	A	B	C	D	E	F	G	*/
 	S_SPC1,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,
+
+  /*	H	I	J	K	L	M	N	O	*/
 	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,
+
+  /*	P	Q	R	S	T	U	V	W	*/
 	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,
+
+  /*	X	Y	Z	[	\	]	^	_	*/
 	S_ALP,	S_ALP,	S_ALP,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ALP,
 
+  /*	`	a	b	c	d	e	f	g	*/
 	S_ERR,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,
+
+  /*	h	i	j	k	l	m	n	o	*/
 	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,
+
+  /*	p	q	r	s	t	u	v	w	*/
 	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,	S_ALP,
+
+  /*	x	y	z	{	|	}	~	del	*/
 	S_ALP,	S_ALP,	S_ALP,	S_LBRA,	S_ERR,	S_RBRA,	S_ERR,	S_ERR,
 
 	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,
@@ -273,24 +467,52 @@ static const char sh_lexstate6[256] =
  */
 static const char sh_lexstate7[256] =
 {
+  /*	nul	soh	stx	etx	eot	enq	ack	bel	*/
 	S_EOF,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,
-	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,
-	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,
+
+  /*	bs	ht/tab	nl/lf	vt	ff	cr	so	si	*/
 	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,
 
+  /*	dle	dc1	dc2	dc3	dc4	nak	syn	etb	*/
+	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,
+
+  /*	can	em	sub	esc	fs	gs	rs	us	*/
+	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,
+
+  /*	space	!	"	#	$	%	&	'	*/
 	S_ERR,	0,	S_ERR,	S_MOD2,	0,	S_MOD2,	S_ERR,	S_ERR,
+
+  /*	(	)	*	+	,	-	.	/	*/
 	S_ERR,	S_ERR,	S_MOD1,	S_MOD1,	S_ERR,	S_MOD1,	S_DOT,	S_MOD2,
+
+  /*	0	1	2	3	4	5	6	7	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	8	9	:	;	<	=	>	?	*/
 	0,	0,	S_MOD1,	S_ERR,	S_ERR,	S_MOD1,	S_ERR,	S_MOD1,
 
+  /*	@	A	B	C	D	E	F	G	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	H	I	J	K	L	M	N	O	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	P	Q	R	S	T	U	V	W	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	X	Y	Z	[	\	]	^	_	*/
 	0,	0,	0,	S_BRACT,S_ESC,	S_ERR,	S_ERR,	0,
 
+  /*	`	a	b	c	d	e	f	g	*/
 	S_ERR,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	h	i	j	k	l	m	n	o	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	p	q	r	s	t	u	v	w	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	x	y	z	{	|	}	~	del	*/
 	0,	0,	0,	S_ERR,	S_ERR,	S_POP,	S_ERR,	S_ERR,
 
 	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,	S_ERR,
@@ -317,24 +539,52 @@ static const char sh_lexstate7[256] =
  */
 static const char sh_lexstate8[256] =
 {
+  /*	nul	soh	stx	etx	eot	enq	ack	bel	*/
 	S_EOF,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,
-	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,
-	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,
+
+  /*	bs	ht/tab	nl/lf	vt	ff	cr	so	si	*/
 	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,
 
+  /*	dle	dc1	dc2	dc3	dc4	nak	syn	etb	*/
 	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,
+
+  /*	can	em	sub	esc	fs	gs	rs	us	*/
 	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,
+
+  /*	space	!	"	#	$	%	&	'	*/
+	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,
+
+  /*	(	)	*	+	,	-	.	/	*/
+	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,
+
+  /*	0	1	2	3	4	5	6	7	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	8	9	:	;	<	=	>	?	*/
 	0,	0,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,
 
+  /*	@	A	B	C	D	E	F	G	*/
 	S_EDOL,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	H	I	J	K	L	M	N	O	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	P	Q	R	S	T	U	V	W	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	X	Y	Z	[	\	]	^	_	*/
 	0,	0,	0,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	0,
 
+  /*	`	a	b	c	d	e	f	g	*/
 	S_EDOL,0,	0,	0,	0,	0,	0,	0,
+
+  /*	h	i	j	k	l	m	n	o	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	p	q	r	s	t	u	v	w	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	x	y	z	{	|	}	~	del	*/
 	0,	0,	0,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,
 
 	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,	S_EDOL,
@@ -361,21 +611,52 @@ static const char sh_lexstate8[256] =
  */
 static const char sh_lexstate9[256] =
 {
+  /*	nul	soh	stx	etx	eot	enq	ack	bel	*/
 	S_EOF,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	bs	ht/tab	nl/lf	vt	ff	cr	so	si	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	dle	dc1	dc2	dc3	dc4	nak	syn	etb	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	can	em	sub	esc	fs	gs	rs	us	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	space	!	"	#	$	%	&	'	*/
 	0,	S_BRAOP,S_QUOTE,0,	S_DOL,	0,	S_PAT,	S_LIT,
+
+  /*	(	)	*	+	,	-	.	/	*/
 	S_PAT,	S_PAT,	S_PAT,	0,	S_COM,	S_BRAOP,S_DOT,	S_SLASH,
+
+  /*	0	1	2	3	4	5	6	7	*/
 	S_DIG,	S_DIG,	S_DIG,	S_DIG,	S_DIG,	S_DIG,	S_DIG,	S_DIG,
+
+  /*	8	9	:	;	<	=	>	?	*/
 	S_DIG,	S_DIG,	S_COLON,0,	0,	S_EQ,	0,	S_PAT,
+
+  /*	@	A	B	C	D	E	F	G	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	H	I	J	K	L	M	N	O	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	P	Q	R	S	T	U	V	W	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	X	Y	Z	[	\	]	^	_	*/
 	0,	0,	0,	S_BRACT,S_ESC,	S_ENDCH,S_BRAOP,0,
+
+  /*	`	a	b	c	d	e	f	g	*/
 	S_GRAVE,0,	0,	0,	0,	0,	0,	0,
+
+  /*	h	i	j	k	l	m	n	o	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	p	q	r	s	t	u	v	w	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	x	y	z	{	|	}	~	del	*/
 	0,	0,	0,	S_BRACE,S_PAT,	S_ENDCH,0,	0
 };
 
@@ -385,21 +666,52 @@ static const char sh_lexstate9[256] =
  */
 static const char sh_lexstate11[256] =
 {
+  /*	nul	soh	stx	etx	eot	enq	ack	bel	*/
 	S_EOF,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	bs	ht/tab	nl/lf	vt	ff	cr	so	si	*/
 	0,	0,	S_NL,	0,	0,	0,	0,	0,
+
+  /*	dle	dc1	dc2	dc3	dc4	nak	syn	etb	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	can	em	sub	esc	fs	gs	rs	us	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	space	!	"	#	$	%	&	'	*/
 	0,	0,	S_QUOTE,0,	S_DOL,	0,	0,	S_LIT,
+
+  /*	(	)	*	+	,	-	.	/	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	0	1	2	3	4	5	6	7	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	8	9	:	;	<	=	>	?	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	@	A	B	C	D	E	F	G	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	H	I	J	K	L	M	N	O	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	P	Q	R	S	T	U	V	W	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	X	Y	Z	[	\	]	^	_	*/
 	0,	0,	0,	0,	S_ESC,	0,	0,	0,
+
+  /*	`	a	b	c	d	e	f	g	*/
 	S_GRAVE,0,	0,	0,	0,	0,	0,	0,
+
+  /*	h	i	j	k	l	m	n	o	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	p	q	r	s	t	u	v	w	*/
 	0,	0,	0,	0,	0,	0,	0,	0,
+
+  /*	x	y	z	{	|	}	~	del	*/
 	0,	0,	0,	0,	0,	S_RBRA,	0,	0
 };
 
@@ -424,8 +736,6 @@ const char e_lexsyntax4[]	= "syntax error at line %d: invalid reference list";
 const char e_lexsyntax5[]	= "syntax error at line %d: `<<%s' here-document not contained within command substitution";
 const char e_lexwarnvar[]	= "line %d: in '((%s))', using '$' as in '$%.*s' is slower and can introduce rounding errors";
 const char e_lexarithwarn[]	= "line %d: %s is slower than ((%.*s%s";
-const char e_lexlabignore[]	= "line %d: label %s ignored";
-const char e_lexlabunknown[]	= "line %d: %s unknown label";
 const char e_lexobsolete1[]	= "line %d: `...` obsolete, use $(...)";
 const char e_lexobsolete2[]	= "line %d: -a obsolete, use -e";
 const char e_lexobsolete3[]	= "line %d: '=' obsolete, use '=='";
