@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1982-2012 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2024 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -171,7 +171,6 @@ typedef enum
 
 static void draw(Emacs_t*,Draw_t);
 static int escape(Emacs_t*,genchar*, int);
-static void putstring(Emacs_t*,char*);
 static void search(Emacs_t*,genchar*,int);
 static void setcursor(Emacs_t*,int, int);
 static void show_info(Emacs_t*,const char*);
@@ -599,7 +598,7 @@ update:
 				if (ep->terminal == PAPER)
 				{
 					putchar(ep->ed,'\n');
-					putstring(ep,Prompt);
+					ed_putstring(ep->ed,Prompt);
 				}
 				c = ed_getchar(ep->ed,0);
 				if (c != usrkill)
@@ -613,7 +612,7 @@ update:
 				{
 					ep->terminal = PAPER;
 					putchar(ep->ed,'\n');
-					putstring(ep,Prompt);
+					ed_putstring(ep->ed,Prompt);
 				}
 			}
 			continue;
@@ -659,9 +658,7 @@ update:
 			{
 				hline = hismin+1;
 				beep();
-#ifndef ESH_NFIRST
 				continue;
-#endif
 			}
 			goto common;
 
@@ -784,14 +781,6 @@ static void show_info(Emacs_t *ep,const char *str)
 	draw(ep,UPDATE);
 }
 
-static void putstring(Emacs_t* ep,char *sp)
-{
-	int c;
-	while (c= *sp++)
-		 putchar(ep->ed,c);
-}
-
-
 static int escape(Emacs_t* ep,genchar *out,int count)
 {
 	int i,value;
@@ -1348,7 +1337,7 @@ static void xcommands(Emacs_t *ep,int count)
 			}
 			return;
 
-#	define itos(i)	fmtbase((intmax_t)(i),0,0)	/* want signed conversion */
+#	define itos(i)	fmtint(i,0)	/* want signed conversion */
 
 		case cntl('H'):		/* ^X^H show history info */
 			{
@@ -1547,10 +1536,10 @@ static void draw(Emacs_t *ep,Draw_t option)
 #define	BOTH   '*'
 #define	UPPER  '>'
 
-	genchar *sptr;		/* Pointer within screen */
+	genchar *sptr;			/* Pointer within screen */
 	genchar nscreen[2*MAXLINE];	/* New entire screen */
 	genchar *ncursor;		/* New cursor */
-	genchar *nptr;		/* Pointer to New screen */
+	genchar *nptr;			/* Pointer to New screen */
 	char  longline;			/* Line overflow */
 	genchar *logcursor;
 	genchar *nscend;		/* end of logical screen */
@@ -1574,7 +1563,7 @@ static void draw(Emacs_t *ep,Draw_t option)
 			return;
 		}
 		*ep->cursor = '\0';
-		putstring(ep,Prompt);	/* start with prompt */
+		ed_putstring(ep->ed,Prompt);	/* start with prompt */
 	}
 	
 	/*********************
