@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1982-2012 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2024 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -25,7 +25,7 @@
 #include	<sfio.h>
 
 #ifndef IOBSIZE
-#   define  IOBSIZE	(SF_BUFSIZE*sizeof(char*))
+#   define  IOBSIZE	(SFIO_BUFSIZE*sizeof(char*))
 #endif /* IOBSIZE */
 #define IOMAXTRY	20
 
