@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1982-2012 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2024 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -14,6 +14,7 @@
 *                  Martijn Dekker <martijn@inlv.org>                   *
 *          atheik <14833674+atheik@users.noreply.github.com>           *
 *            Johnothan King <johnothanking@protonmail.com>             *
+*               K. Eugene Carlson <kvngncrlsn@gmail.com>               *
 *                                                                      *
 ***********************************************************************/
 
@@ -472,11 +473,11 @@ void sh_ioinit(void)
 	sh.errbuff = (char*)sh_malloc(IOBSIZE/4);
 	sfsetbuf(sfstderr,sh.errbuff,IOBSIZE/4);
 	sfsetbuf(sfstdout,sh.outbuff,IOBSIZE);
-	sfpool(sfstdout,sh.outpool,SF_WRITE);
-	sfpool(sfstderr,sh.outpool,SF_WRITE);
-	sfset(sfstdout,SF_LINE,0);
-	sfset(sfstderr,SF_LINE,0);
-	sfset(sfstdin,SF_SHARE|SF_PUBLIC,1);
+	sfpool(sfstdout,sh.outpool,SFIO_WRITE);
+	sfpool(sfstderr,sh.outpool,SFIO_WRITE);
+	sfset(sfstdout,SFIO_LINE,0);
+	sfset(sfstderr,SFIO_LINE,0);
+	sfset(sfstdin,SFIO_SHARE|SFIO_PUBLIC,1);
 }
 
 /*
@@ -485,9 +486,9 @@ void sh_ioinit(void)
 static int outexcept(Sfio_t *iop,int type,void *data,Sfdisc_t *handle)
 {
 	static int	active = 0;
-	if(type==SF_DPOP || type==SF_FINAL)
+	if(type==SFIO_DPOP || type==SFIO_FINAL)
 		free(handle);
-	else if(type==SF_WRITE && (*(ssize_t*)data)<0 && sffileno(iop)!=2)
+	else if(type==SFIO_WRITE && (*(ssize_t*)data)<0 && sffileno(iop)!=2)
 		switch (errno)
 		{
 		case EINTR:
@@ -507,7 +508,7 @@ static int outexcept(Sfio_t *iop,int type,void *data,Sfdisc_t *handle)
 				active = 1;
 				((struct checkpt*)sh.jmplist)->mode = 0;
 				sfpurge(iop);
-				sfpool(iop,NULL,SF_WRITE);
+				sfpool(iop,NULL,SFIO_WRITE);
 				errno = save;
 				/*
 				 * Note: UNREACHABLE() is avoided here because this errormsg() call will return.
@@ -535,7 +536,7 @@ Sfio_t *sh_iostream(int fd)
 {
 	Sfio_t *iop;
 	int status = sh_iocheckfd(fd);
-	int flags = SF_WRITE;
+	int flags = SFIO_WRITE;
 	char *bp;
 	Sfdisc_t *dp;
 	if(status==IOCLOSE)
@@ -554,18 +555,18 @@ Sfio_t *sh_iostream(int fd)
 	if(status&IOREAD)
 	{
 		bp = (char *)sh_malloc(IOBSIZE+1);
-		flags |= SF_READ;
+		flags |= SFIO_READ;
 		if(!(status&IOWRITE))
-			flags &= ~SF_WRITE;
+			flags &= ~SFIO_WRITE;
 	}
 	else
 		bp = sh.outbuff;
 	if(status&IODUP)
-		flags |= SF_SHARE|SF_PUBLIC;
+		flags |= SFIO_SHARE|SFIO_PUBLIC;
 	if((iop = sh.sftable[fd]) && sffileno(iop)>=0)
 	{
 		if(status&IOTTY)
-			sfset(iop,SF_LINE|SF_WCWIDTH,1);
+			sfset(iop,SFIO_LINE|SFIO_WCWIDTH,1);
 		sfsetbuf(iop, bp, IOBSIZE);
 	}
 	else if(!(iop=sfnew((fd<=2?iop:0),bp,IOBSIZE,fd,flags)))
@@ -573,16 +574,16 @@ Sfio_t *sh_iostream(int fd)
 	dp = sh_newof(0,Sfdisc_t,1,0);
 	if(status&IOREAD)
 	{
-		sfset(iop,SF_MALLOC,1);
+		sfset(iop,SFIO_MALLOC,1);
 		if(!(status&IOWRITE))
-			sfset(iop,SF_IOCHECK,1);
+			sfset(iop,SFIO_IOCHECK,1);
 		dp->exceptf = slowexcept;
 		if(status&IOTTY)
 			dp->readf = slowread;
 		else if(status&IONOSEEK)
 		{
 			dp->readf = piperead;
-			sfset(iop, SF_IOINTR,1);
+			sfset(iop, SFIO_IOINTR,1);
 		}
 		else
 			dp->readf = 0;
@@ -595,7 +596,7 @@ Sfio_t *sh_iostream(int fd)
 			dp->exceptf = pipeexcept;
 		else
 			dp->exceptf = outexcept;
-		sfpool(iop,sh.outpool,SF_WRITE);
+		sfpool(iop,sh.outpool,SFIO_WRITE);
 	}
 	sfdisc(iop,dp);
 	sh.sftable[fd] = iop;
@@ -667,7 +668,7 @@ int sh_iorenumber(int f1,int f2)
 			sh.fdstatus[f2] = (sh.fdstatus[f1]&~IOCLEX);
 			sfsetfd(spnew,f2);
 			sfswap(spnew,sp);
-			sfset(sp,SF_SHARE|SF_PUBLIC,1);
+			sfset(sp,SFIO_SHARE|SFIO_PUBLIC,1);
 		}
 		else 
 		{
@@ -689,7 +690,7 @@ int sh_iorenumber(int f1,int f2)
 	{
 		sfsetfd(sp,f2);
 		if(f2<=2)
-			sfset(sp,SF_SHARE|SF_PUBLIC,1);
+			sfset(sp,SFIO_SHARE|SFIO_PUBLIC,1);
 	}
 	if(f2>=sh.lim.open_max)
 		sh_iovalidfd(f2);
@@ -867,7 +868,7 @@ int sh_open(const char *path, int flags, ...)
 		mode = IOREAD;
 	if(fd >= sh.lim.open_max)
 		sh_iovalidfd(fd);
-	if((sp = sh.sftable[fd]) && (sfset(sp,0,0) & SF_STRING))
+	if((sp = sh.sftable[fd]) && (sfset(sp,0,0) & SFIO_STRING))
 	{
 		int n,err=errno;
 		if((n = sh_fcntl(fd,F_DUPFD,10)) >= 10)
@@ -986,12 +987,12 @@ static int io_patseek(regex_t *rp, Sfio_t* sp, int flags)
 {
 	char	*cp, *match;
 	int	r, fd=sffileno(sp), close_exec = sh.fdstatus[fd]&IOCLEX;
-	int	was_share,s=(PIPE_BUF>SF_BUFSIZE?SF_BUFSIZE:PIPE_BUF);
+	int	was_share,s=(PIPE_BUF>SFIO_BUFSIZE?SFIO_BUFSIZE:PIPE_BUF);
 	size_t	n,m;
 	sh.fdstatus[sffileno(sp)] |= IOCLEX;
 	if(fd==0)
-		was_share = sfset(sp,SF_SHARE,1);
-	while((cp=sfreserve(sp, -s, SF_LOCKR)) || (cp=sfreserve(sp,SF_UNBOUND, SF_LOCKR)))
+		was_share = sfset(sp,SFIO_SHARE,1);
+	while((cp=sfreserve(sp, -s, SFIO_LOCKR)) || (cp=sfreserve(sp,SFIO_UNBOUND, SFIO_LOCKR)))
 	{
 		m = n = sfvalue(sp);
 		while(n>0 && cp[n-1]!='\n')
@@ -1014,8 +1015,8 @@ static int io_patseek(regex_t *rp, Sfio_t* sp, int flags)
 	}
 	if(!close_exec)
 		sh.fdstatus[sffileno(sp)] &= ~IOCLEX;
-	if(fd==0 && !(was_share&SF_SHARE))
-		sfset(sp, SF_SHARE,0);
+	if(fd==0 && !(was_share&SFIO_SHARE))
+		sfset(sp, SFIO_SHARE,0);
 	return 0;
 }
 
@@ -1122,11 +1123,11 @@ int	sh_redirect(struct ionod *iop, int flag)
 {
 	Sfoff_t off; 
 	char *fname;
-	int 	fd, iof;
+	int fd = -1, iof;
 	const char *message = e_open;
 	int o_mode;		/* mode flag for open */
 	static char io_op[7];	/* used for -x trace info */
-	int trunc=0, clexec=0, fn, traceon;
+	int trunc=0, clexec=0, fn, traceon=0;
 	int r, indx = sh.topfd, perm= -1;
 	char *tname=0, *after="", *trace = sh.st.trap[SH_DEBUGTRAP];
 	Namval_t *np=0;
@@ -1189,7 +1190,7 @@ int	sh_redirect(struct ionod *iop, int flag)
 		{
 			if(iof&IOLSEEK)
 			{
-				struct argnod *ap = (struct argnod*)stkalloc(sh.stk,ARGVAL+strlen(iop->ioname));
+				struct argnod *ap = stkalloc(sh.stk,ARGVAL+strlen(iop->ioname));
 				memset(ap, 0, ARGVAL);
 				ap->argflag = ARG_MAC;
 				strcpy(ap->argval,iop->ioname);
@@ -1201,7 +1202,7 @@ int	sh_redirect(struct ionod *iop, int flag)
 		if((iof&IOPROCSUB) && !(iof&IOLSEEK))
 		{
 			/* handle process substitution passed to redirection */
-			struct argnod *ap = (struct argnod*)stkalloc(sh.stk,ARGVAL+strlen(iop->ioname));
+			struct argnod *ap = stkalloc(sh.stk,ARGVAL+strlen(iop->ioname));
 			memset(ap, 0, ARGVAL);
 			if(iof&IOPUT)
 				ap->argflag = ARG_RAW;
@@ -1401,7 +1402,7 @@ int	sh_redirect(struct ionod *iop, int flag)
 				sfprintf(sfstderr,"%s %s%s%c",io_op,fname,after,iop->ionxt?' ':'\n');
 			}
 			if(flag==SH_SHOWME)
-				return indx;
+				continue;
 			if(trace && fname)
 			{
 				char *argv[7], **av=argv;
@@ -1620,12 +1621,12 @@ static int io_heredoc(struct ionod *iop, const char *name, int traceon)
 		if(fno>=0 || (iop->iofile&IOQUOTE))
 		{
 			/* This is a quoted here-document, not expansion */
-			sfmove(infile,tmp,SF_UNBOUND,-1);
+			sfmove(infile,tmp,SFIO_UNBOUND,-1);
 			sfclose(infile);
 			if(sffileno(tmp)>0)
 			{
 				sfsetbuf(tmp,sh_malloc(IOBSIZE+1),IOBSIZE);
-				sfset(tmp,SF_MALLOC,1);
+				sfset(tmp,SFIO_MALLOC,1);
 			}
 			sfseek(sh.heredocs,off,SEEK_SET);
 			if(fno>=0)
@@ -1670,7 +1671,7 @@ static ssize_t tee_write(Sfio_t *iop,const void *buff,size_t n,Sfdisc_t *unused)
  */
 void sh_iosave(int origfd, int oldtop, char *name)
 {
-	int	savefd;
+	int savefd;
 	int flag = (oldtop&(IOSUBSHELL|IOPICKFD));
 	oldtop &= ~(IOSUBSHELL|IOPICKFD);
 	/* see if already saved, only save once */
@@ -1768,7 +1769,7 @@ void	sh_iounsave(void)
  */
 void	sh_iorestore(int last, int jmpval)
 {
-	int 	origfd, savefd, fd;
+	int origfd, savefd, fd;
 	int flag = (last&IOSUBSHELL);
 	last &= ~IOSUBSHELL;
 	for (fd = sh.topfd - 1; fd >= last; fd--)
@@ -1865,14 +1866,14 @@ int sh_ioaccess(int fd,int mode)
 static int slowexcept(Sfio_t *iop,int type,void *data,Sfdisc_t *handle)
 {
 	int	n,fno;
-	if(type==SF_DPOP || type==SF_FINAL)
+	if(type==SFIO_DPOP || type==SFIO_FINAL)
 		free(handle);
-	if(type==SF_WRITE && ERROR_PIPE(errno))
+	if(type==SFIO_WRITE && ERROR_PIPE(errno))
 	{
 		sfpurge(iop);
 		return -1;
 	}
-	if(type!=SF_READ)
+	if(type!=SFIO_READ)
 		return 0;
 	if((sh.trapnote&(SH_SIGSET|SH_SIGTRAP)) && errno!=EIO && errno!=ENXIO)
 		errno = EINTR;
@@ -1960,7 +1961,7 @@ static ssize_t piperead(Sfio_t *iop,void *buff,size_t size,Sfdisc_t *handle)
 	if(sh_isstate(SH_INTERACTIVE) && fd==0 && io_prompt(iop,sh.nextprompt)<0 && errno==EIO)
 		return 0;
 	sh_onstate(SH_TTYWAIT);
-	if(!(sh.fdstatus[fd]&IOCLEX) && (sfset(iop,0,0)&SF_SHARE))
+	if(!(sh.fdstatus[fd]&IOCLEX) && (sfset(iop,0,0)&SFIO_SHARE))
 		size = ed_read(sh.ed_context, fd, (char*)buff, size,0);
 	else
 		size = sfrd(iop,buff,size,handle);
@@ -2014,7 +2015,7 @@ static ssize_t slowread(Sfio_t *iop,void *buff,size_t size,Sfdisc_t *handle)
 			sh_timerdel(timeout);
 		timeout=0;
 #if SHOPT_HISTEXPAND
-		if(rsize && *(char*)buff != '\n' && sh.nextprompt==1 && sh_isoption(SH_HISTEXPAND))
+		if(rsize > 0 && *(char*)buff != '\n' && sh.nextprompt==1 && sh_isoption(SH_HISTEXPAND))
 		{
 			int r;
 			((char*)buff)[rsize] = '\0';
@@ -2155,7 +2156,7 @@ static int	io_prompt(Sfio_t *iop,int flag)
 		flag = 0;
 	if(flag==0)
 		return sfsync(sfstderr);
-	sfflags = sfset(sfstderr,SF_SHARE|SF_PUBLIC|SF_READ,0);
+	sfflags = sfset(sfstderr,SFIO_SHARE|SFIO_PUBLIC|SFIO_READ,0);
 	if(!(sh.prompt=(char*)sfreserve(sfstderr,0,0)))
 		sh.prompt = "";
 	switch(flag)
@@ -2200,7 +2201,7 @@ static int	io_prompt(Sfio_t *iop,int flag)
 			/* PS2 prompt. Save stack state to avoid corrupting command substitutions
 			 * in case we're executing a PS2.get discipline function at parse time. */
 			int	savestacktop = stktell(sh.stk);
-			char	*savestackptr = stkfreeze(sh.stk,0);
+			void	*savestackptr = stkfreeze(sh.stk,0);
 			cp = nv_getval(sh_scoped(PS2NOD));
 			stkset(sh.stk, savestackptr, savestacktop);
 			break;
@@ -2216,7 +2217,7 @@ static int	io_prompt(Sfio_t *iop,int flag)
 done:
 	if(*sh.prompt && (endprompt=(char*)sfreserve(sfstderr,0,0)))
 		*endprompt = 0;
-	sfset(sfstderr,sfflags&SF_READ|SF_SHARE|SF_PUBLIC,1);
+	sfset(sfstderr,sfflags&SFIO_READ|SFIO_SHARE|SFIO_PUBLIC,1);
 	return sfsync(sfstderr);
 }
 
@@ -2226,9 +2227,9 @@ done:
  */
 static int pipeexcept(Sfio_t* iop, int mode, void *data, Sfdisc_t* handle)
 {
-	if(mode==SF_DPOP || mode==SF_FINAL)
+	if(mode==SFIO_DPOP || mode==SFIO_FINAL)
 		free(handle);
-	else if(mode==SF_WRITE && ERROR_PIPE(errno))
+	else if(mode==SFIO_WRITE && ERROR_PIPE(errno))
 	{
 		sfpurge(iop);
 		return -1;
@@ -2245,21 +2246,21 @@ static void	sftrack(Sfio_t* sp, int flag, void* data)
 	struct checkpt *pp;
 	int mode;
 	int newfd = integralof(data);
-	if(flag==SF_SETFD || flag==SF_CLOSING)
+	if(flag==SFIO_SETFD || flag==SFIO_CLOSING)
 	{
 		if(newfd<0)
-			flag = SF_CLOSING;
+			flag = SFIO_CLOSING;
 		if(fdnotify)
-			(*fdnotify)(sffileno(sp),flag==SF_CLOSING?-1:newfd);
+			(*fdnotify)(sffileno(sp),flag==SFIO_CLOSING?-1:newfd);
 	}
 #ifdef DEBUG
-	if(flag==SF_READ || flag==SF_WRITE)
+	if(flag==SFIO_READ || flag==SFIO_WRITE)
 	{
-		char *z = fmtbase((intmax_t)sh.current_pid,0,0);
+		char *z = fmtint(sh.current_pid,0);
 		write(ERRIO,z,strlen(z));
 		write(ERRIO,": ",2);
 		write(ERRIO,"attempt to ",11);
-		if(flag==SF_READ)
+		if(flag==SFIO_READ)
 			write(ERRIO,"read from",9);
 		else
 			write(ERRIO,"write to",8);
@@ -2272,20 +2273,20 @@ static void	sftrack(Sfio_t* sp, int flag, void* data)
 	if(sh_isstate(SH_NOTRACK))
 		return;
 	mode = sfset(sp,0,0);
-	if(sp==sh.heredocs && fd < 10 && flag==SF_SETFD)
+	if(sp==sh.heredocs && fd < 10 && flag==SFIO_SETFD)
 	{
 		fd = sfsetfd(sp,10);
 		fcntl(fd,F_SETFD,FD_CLOEXEC);
 	}
 	if(fd < 3)
 		return;
-	if(flag==SF_NEW)
+	if(flag==SFIO_NEW)
 	{
 		if(!sh.sftable[fd] && sh.fdstatus[fd]==IOCLOSE)
 		{
 			sh.sftable[fd] = sp;
-			flag = (mode&SF_WRITE)?IOWRITE:0;
-			if(mode&SF_READ)
+			flag = (mode&SFIO_WRITE)?IOWRITE:0;
+			if(mode&SFIO_READ)
 				flag |= IOREAD;
 			sh.fdstatus[fd] = flag;
 			sh_iostream(fd);
@@ -2306,7 +2307,7 @@ static void	sftrack(Sfio_t* sp, int flag, void* data)
 		if(fdnotify)
 			(*fdnotify)(-1,sffileno(sp));
 	}
-	else if(flag==SF_CLOSING || (flag==SF_SETFD  && newfd<=2))
+	else if(flag==SFIO_CLOSING || (flag==SFIO_SETFD  && newfd<=2))
 	{
 		sh.sftable[fd] = 0;
 		sh.fdstatus[fd]=IOCLOSE;
@@ -2368,11 +2369,11 @@ static int eval_exceptf(Sfio_t *iop,int type, void *data, Sfdisc_t *handle)
 	int	len;
 
 	/* no more to do */
-	if(type!=SF_READ || !(cp = ep->argv[0]))
+	if(type!=SFIO_READ || !(cp = ep->argv[0]))
 	{
-		if(type==SF_CLOSING)
-			sfdisc(iop,SF_POPDISC);
-		else if(ep && (type==SF_DPOP || type==SF_FINAL))
+		if(type==SFIO_CLOSING)
+			sfdisc(iop,SFIO_POPDISC);
+		else if(ep && (type==SFIO_DPOP || type==SFIO_FINAL))
 			free(ep);
 		return 0;
 	}
@@ -2410,7 +2411,7 @@ static Sfio_t *subopen(Sfio_t* sp, off_t offset, long size)
 	disp->oldsp = sp;
 	disp->offset = offset;
 	disp->size = disp->left = size;
-	sp = sfnew(NULL,(char*)(disp+1),IOBSIZE,PSEUDOFD,SF_READ);
+	sp = sfnew(NULL,(char*)(disp+1),IOBSIZE,PSEUDOFD,SFIO_READ);
 	sfdisc(sp,&disp->disc);
 	return sp;
 }
@@ -2441,23 +2442,23 @@ static ssize_t subread(Sfio_t* sp,void* buff,size_t size,Sfdisc_t* handle)
 static int subexcept(Sfio_t* sp,int mode, void *data, Sfdisc_t* handle)
 {
 	struct subfile *disp = (struct subfile*)handle;
-	if(mode==SF_CLOSING)
+	if(mode==SFIO_CLOSING)
 	{
-		sfdisc(sp,SF_POPDISC);
+		sfdisc(sp,SFIO_POPDISC);
 		sfsetfd(sp,-1);
 		return 0;
 	}
-	else if(disp && (mode==SF_DPOP || mode==SF_FINAL))
+	else if(disp && (mode==SFIO_DPOP || mode==SFIO_FINAL))
 	{
 		free(disp);
 		return 0;
 	}
-	else if (mode==SF_ATEXIT)
+	else if (mode==SFIO_ATEXIT)
 	{
-		sfdisc(sp, SF_POPDISC);
+		sfdisc(sp, SFIO_POPDISC);
 		return 0;
 	}
-	else if(mode==SF_READ)
+	else if(mode==SFIO_READ)
 		return 0;
 	return -1;
 }
@@ -2553,7 +2554,7 @@ ssize_t sh_write(int fd, const void* buff, size_t n)
 off_t sh_seek(int fd, off_t offset, int whence)
 {
 	Sfio_t *sp;
-	if((sp=sh.sftable[fd]) && (sfset(sp,0,0)&(SF_READ|SF_WRITE)))
+	if((sp=sh.sftable[fd]) && (sfset(sp,0,0)&(SFIO_READ|SFIO_WRITE)))
 		return sfseek(sp,offset,whence);
 	else
 		return lseek(fd,offset,whence);
@@ -2614,7 +2615,7 @@ mode_t	sh_umask(mode_t m)
 
 /*
  * give file descriptor <fd> and <mode>, return an iostream pointer
- * <mode> must be SF_READ or SF_WRITE
+ * <mode> must be SFIO_READ or SFIO_WRITE
  * <fd> must be a non-negative number ofr SH_IOCOPROCESS or SH_IOHISTFILE. 
  * returns NULL on failure and may set errno.
  */
@@ -2622,7 +2623,7 @@ Sfio_t *sh_iogetiop(int fd, int mode)
 {
 	int n;
 	Sfio_t *iop=0;
-	if(mode!=SF_READ && mode!=SF_WRITE)
+	if(mode!=SFIO_READ && mode!=SFIO_WRITE)
 	{
 		errno = EINVAL;
 		return iop;
@@ -2635,7 +2636,7 @@ Sfio_t *sh_iogetiop(int fd, int mode)
 		fd = sffileno(sh.hist_ptr->histfp);
 		break;
 	    case SH_IOCOPROCESS:
-		if(mode==SF_WRITE)
+		if(mode==SFIO_WRITE)
 			fd = sh.coutpipe;
 		else
 			fd = sh.cpipe[0];
@@ -2651,9 +2652,9 @@ Sfio_t *sh_iogetiop(int fd, int mode)
 	}
 	if(!(n=sh.fdstatus[fd]))
 		n = sh_iocheckfd(fd);
-	if(mode==SF_WRITE && !(n&IOWRITE))
+	if(mode==SFIO_WRITE && !(n&IOWRITE))
 		return iop;
-	if(mode==SF_READ && !(n&IOREAD))
+	if(mode==SFIO_READ && !(n&IOREAD))
 		return iop;
 	if(!(iop = sh.sftable[fd]))
 		iop=sh_iostream(fd);
@@ -2678,9 +2679,9 @@ Sfio_t	*sh_fd2sfio(int fd)
 	{
 		int flags=0;
 		if(status&IOREAD)
-			flags |= SF_READ;
+			flags |= SFIO_READ;
 		if(status&IOWRITE)
-			flags |= SF_WRITE;
+			flags |= SFIO_WRITE;
 		sp = sfnew(NULL, NULL, -1, fd,flags);
 		sh.sftable[fd] = sp;
 	}
