@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1982-2012 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2024 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -79,7 +79,6 @@ static struct subshell
 	int		tmpfd;	/* saved tmp file descriptor */
 	int		pipefd;	/* read fd if pipe is created */
 	char		jobcontrol;
-	char		monitor;
 	unsigned char	fdstatus;
 	int		fdsaved; /* bit mask for saved file descriptors */
 	int		sig;	/* signal for $$ */
@@ -89,9 +88,9 @@ static struct subshell
 	int		cpipe;
 	char		subshare;
 	char		comsub;
-	unsigned int	rand_seed;  /* parent shell $RANDOM seed */
-	int		rand_last;  /* last random number from $RANDOM in parent shell */
-	int		rand_state; /* 0 means sp->rand_seed hasn't been set, 1 is the opposite */
+	unsigned int	rand_seed;          /* parent shell $RANDOM seed */
+	int		rand_last;          /* last random number from $RANDOM in parent shell */
+	int		rand_state;         /* 0 means sp->rand_seed hasn't been set, 1 is the opposite */
 #if _lib_fchdir
 	int		pwdfd;	/* file descriptor for PWD */
 	char		pwdclose;
@@ -108,7 +107,7 @@ static unsigned int subenv;
  */
 void	sh_subtmpfile(void)
 {
-	if(sfset(sfstdout,0,0)&SF_STRING)
+	if(sfset(sfstdout,0,0)&SFIO_STRING)
 	{
 		int fd;
 		struct checkpt	*pp = (struct checkpt*)sh.jmplist;
@@ -126,7 +125,7 @@ void	sh_subtmpfile(void)
 			UNREACHABLE();
 		}
 		/* popping a discipline forces a /tmp file create */
-		sfdisc(sfstdout,SF_POPDISC);
+		sfdisc(sfstdout,SFIO_POPDISC);
 		if((fd=sffileno(sfstdout))<0)
 		{
 			errormsg(SH_DICT,ERROR_SYSTEM|ERROR_PANIC,"could not create temp file");
@@ -143,8 +142,8 @@ void	sh_subtmpfile(void)
 			sh.fdstatus[fd] = IOCLOSE;
 		}
 		sh_iostream(1);
-		sfset(sfstdout,SF_SHARE|SF_PUBLIC,1);
-		sfpool(sfstdout,sh.outpool,SF_WRITE);
+		sfset(sfstdout,SFIO_SHARE|SFIO_PUBLIC,1);
+		sfpool(sfstdout,sh.outpool,SFIO_WRITE);
 		if(pp && pp->olist  && pp->olist->strm == sfstdout)
 			pp->olist->strm = 0;
 	}
@@ -349,7 +348,7 @@ static void nv_restore(struct subshell *sp)
 		}
 		nv_setsize(mp,nv_size(np));
 		if(!(flags&NV_MINIMAL))
-			mp->nvenv = np->nvenv;
+			mp->nvmeta = np->nvmeta;
 		mp->nvfun = np->nvfun;
 		if(np->nvfun && nofree)
 			np->nvfun->nofree = nofree;
@@ -364,7 +363,7 @@ static void nv_restore(struct subshell *sp)
 		else
 			mp->nvalue = np->nvalue;
 		if(nofree && np->nvfun && !np->nvfun->nofree)
-			free((char*)np->nvfun);
+			free(np->nvfun);
 		np->nvfun = 0;
 		if(nv_isattr(mp,NV_EXPORT))
 		{
@@ -595,7 +594,6 @@ Sfio_t *sh_subshell(Shnode_t *t, volatile int flags, int comsub)
 			/* disable job control */
 			sh.spid = 0;
 			sp->jobcontrol = job.jobcontrol;
-			sp->monitor = (sh_isstate(SH_MONITOR)!=0);
 			job.jobcontrol=0;
 			sh_offstate(SH_MONITOR);
 			sp->pipe = sp;
@@ -612,7 +610,7 @@ Sfio_t *sh_subshell(Shnode_t *t, volatile int flags, int comsub)
 				UNREACHABLE();
 			}
 			sfswap(iop,sfstdout);
-			sfset(sfstdout,SF_READ,0);
+			sfset(sfstdout,SFIO_READ,0);
 			sh.fdstatus[1] = IOWRITE;
 			flags |= sh_state(SH_NOFORK);
 		}
@@ -642,13 +640,14 @@ Sfio_t *sh_subshell(Shnode_t *t, volatile int flags, int comsub)
 			/* Virtual subshells are not safe to suspend (^Z, SIGTSTP) in the interactive main shell. */
 			if(sh_isstate(SH_INTERACTIVE))
 			{
+				sh_offstate(SH_INTERACTIVE);
 				sh_offstate(SH_TTYWAIT);
 				if(comsub)
 					sigblock(SIGTSTP);
 				else
 					sh_subfork();
 			}
-			sh_offstate(SH_INTERACTIVE);
+			sh_offstate(SH_PROFILE);
 			sh_exec(t,flags);
 		}
 	}
@@ -657,7 +656,6 @@ Sfio_t *sh_subshell(Shnode_t *t, volatile int flags, int comsub)
 		/* trap on EXIT not handled by child */
 		char *trap=sh.st.trapcom[0];
 		sh.st.trapcom[0] = 0;	/* prevent recursion */
-		sh.oldexit = sh.exitval;
 		sh_trap(trap,0);
 		free(trap);
 	}
@@ -681,7 +679,7 @@ Sfio_t *sh_subshell(Shnode_t *t, volatile int flags, int comsub)
 			sigrelease(SIGTSTP);
 		/* re-enable job control */
 		job.jobcontrol = sp->jobcontrol;
-		if(sp->monitor)
+		if(savst.states & sh_state(SH_MONITOR))
 			sh_onstate(SH_MONITOR);
 		if(sp->pipefd>=0)
 		{
@@ -693,9 +691,9 @@ Sfio_t *sh_subshell(Shnode_t *t, volatile int flags, int comsub)
 		{
 			if(sh.spid)
 			{
-				int e = sh.exitval;
+				int e = sh.exitval, c = sh.chldexitsig;
 				job_wait(sh.spid);
-				sh.exitval = e;
+				sh.exitval = e, sh.chldexitsig = c;
 				if(sh.pipepid==sh.spid)
 					sh.spid = 0;
 				sh.pipepid = 0;
@@ -725,7 +723,7 @@ Sfio_t *sh_subshell(Shnode_t *t, volatile int flags, int comsub)
 				sh.fdstatus[fd] = (sh.fdstatus[1]|IOCLEX);
 				sh.fdstatus[1] = IOCLOSE;
 			}
-			sfset(iop,SF_READ,1);
+			sfset(iop,SFIO_READ,1);
 		}
 		if(sp->saveout)
 			sfswap(sp->saveout,sfstdout);
