@@ -2,7 +2,7 @@
 #                                                                      #
 #               This software is part of the ast package               #
 #          Copyright (c) 1982-2012 AT&T Intellectual Property          #
-#          Copyright (c) 2020-2023 Contributors to ksh 93u+m           #
+#          Copyright (c) 2020-2024 Contributors to ksh 93u+m           #
 #                      and is licensed under the                       #
 #                 Eclipse Public License, Version 2.0                  #
 #                                                                      #
@@ -21,8 +21,16 @@
 
 . "${SHTESTS_COMMON:-${0%/*}/_common}"
 
-integer hasposix=0
-(set -o posix) 2>/dev/null && ((hasposix++))	# not using [[ -o ?posix ]] as it's broken on 93v-
+enum bool=(false true)
+
+bool HAVE_signbit=false
+if	typeset -f .sh.math.signbit >/dev/null && (( signbit(-NaN) ))
+then	HAVE_signbit=true
+else	warning "-lm does not support signbit(-NaN)"
+fi
+
+bool HAVE_posix=false
+(set -o posix) 2>/dev/null && HAVE_posix=true	# not using [[ -o ?posix ]] as it's broken on 93v-
 
 trap '' FPE # NOTE: osf.alpha requires this (no ieee math)
 
@@ -351,7 +359,7 @@ unset x
 x=010
 (( x == 10 )) || err_exit 'leading zeros in x treated as octal arithmetic with ((x))'
 (( $x == 10 )) || err_exit 'leading zeros in x treated as octal arithmetic with (($x))'
-if	((hasposix))
+if	((HAVE_posix))
 then	set --posix
 	((x == 8)) || err_exit 'posix: leading zeros in x not treated as octal arithmetic with ((x))'
 	(($x == 8)) || err_exit 'posix: leading zeros in x not treated as octal arithmetic with (($x))'
@@ -454,8 +462,8 @@ then	set \
 		Inf		inf	\
 		-Inf		-inf	\
 		Nan		nan	\
-		-Nan		-nan	\
 		1.0/0.0		inf
+	((HAVE_signbit)) && set -- "$@" -Nan -nan
 	while	(( $# >= 2 ))
 	do	x=$(printf "%g\n" $(($1)))
 		[[ $x == $2 ]] || err_exit "printf '%g\\n' \$(($1)) failed -- expected $2, got $x"
@@ -691,10 +699,11 @@ unset x
 let x=010
 [[ $x == 10 ]] || err_exit 'let treating 010 as octal'
 (set -o letoctal; let x=010; [[ $x == 8 ]]) || err_exit 'let not treating 010 as octal with letoctal on'
-if [[ -o ?posix ]]
+if	((HAVE_posix))
 then	(set -o posix; let x=010; [[ $x == 8 ]]) || err_exit 'let not treating 010 as octal with posix on'
 fi
 
+unset A
 float z=0
 integer aa=2 a=1
 typeset -A A
@@ -746,7 +755,7 @@ print -- -020 | read x
 ((x == -20)) || err_exit 'numbers with leading -0 treated as octal outside ((...))'
 print -- -8#20 | read x
 ((x == -16)) || err_exit 'numbers with leading -8# should be treated as octal'
-if	((hasposix))
+if	((HAVE_posix))
 then	set --posix
 	(($r == 16)) || err_exit 'posix: leading 0 not treated as octal inside ((...))'
 	x=$(($r))
@@ -772,7 +781,7 @@ let "$x==10" || err_exit 'arithmetic with $x where $x is 010 should be decimal i
 x010=99
 ((x$x == 99 )) || err_exit 'arithmetic with x$x where x=010 should be $x010'
 (( 3+$x == 13 )) || err_exit '3+$x where x=010 should be 13 in ((...))'
-if	((hasposix))
+if	((HAVE_posix))
 then	set --posix
 	(( 3+$x == 11 )) || err_exit 'posix: 3+$x where x=010 should be 11 in ((...))'
 	set --noposix
@@ -904,7 +913,7 @@ unset got
 
 # ======
 # https://github.com/ksh93/ksh/issues/326
-((hasposix)) && for m in u d i o x X
+((HAVE_posix)) && for m in u d i o x X
 do
 	set --posix
 	case $m in
@@ -923,7 +932,7 @@ done
 # BUG_ARITHNAN: In ksh <= 93u+m 2021-11-15 and zsh 5.6 - 5.8, the case-insensitive
 # floating point constants Inf and NaN are recognised in arithmetic evaluation,
 # overriding any variables with the names Inf, NaN, INF, nan, etc.
-if	((hasposix))
+if	((HAVE_posix))
 then	set --posix
 	Inf=42 NaN=13
 	inf=421 nan=137
@@ -992,8 +1001,141 @@ got=$(set +x; eval 'got=$( ((y=1<<4)); echo $y )' 2>&1; echo $got) \
 # ======
 # https://github.com/ksh93/ksh/issues/623
 function .sh.math.add x y { .sh.value=x+y; }
-got=$(PATH=/dev/null; typeset -i z; redirect 2>&1; z='add(2 , 3)'; echo $z)
+got=$(PATH=/dev/null; typeset -i z; set +x; redirect 2>&1; z='add(2 , 3)'; echo $z)
 [[ e=$? -eq 0 && $got == '5' ]] || err_exit ".sh.math.* function parsing: got status $e and $(printf %q "$got")"
 
+# ======
+# arithmetic assignments should not trigger getn disciplines, but the return
+# value should still be cast to the type of the variable that is assigned to
+
+(
+	ulimit -c 0  # fork
+	Errors=0
+	# <<< outdent
+float x
+x.getn() { .sh.value=987.65; }
+let "got = x = 1234.56"
+[[ $got == 1234.56* ]] || err_exit "arithmetic assignment triggers getn discipline (got $got)"
+[[ $x == 987.65* ]] || err_exit "arithmetic comparison fails to trigger getn discipline (got $x)"
+unset x
+whence -q x.getn && err_exit "unset x fails to unset -f x.getn"
+	# >>> indent
+	exit $Errors
+)
+if	let "(e = $?) > 128"
+then	err_exit "getn discipline crashed the shell (got status $e/SIG$(kill -l "$e"))"
+else	let "Errors += e"
+fi
+
+(
+	ulimit -c 0  # fork
+	Errors=0
+	for sz in '' s l
+	do	typeset -${sz}i x=0
+		if	! let "(got = x = 123.95) == 123"
+		then	err_exit "arithmetic assignment does not return properly typecast value (-${sz}i, got $got)"
+		fi
+		typeset -${sz}F x=0
+		let "got = x = 123.95"
+		if	[[ $got != 123.95* ]]  # ignore OS-dependent rounding error
+		then	err_exit "arithmetic assignment does not return properly typecast value (-${sz}F, got $got)"
+		fi
+	done
+	exit $Errors
+)
+if	let "(e = $?) > 128"
+then	err_exit "typeset crashed the shell (got status $e/SIG$(kill -l "$e"))"
+else	let "Errors += e"
+fi
+
+if	! let "(got = RANDOM = 123.95) == 123"
+then	err_exit "arithmetic assignment to RANDOM does not return typecast of assigned value (got $got)"
+fi
+
+let "_ = 123.95, got = _"
+if	[[ $got != '123.95' ]]
+then	err_exit "arithmetic assignment to _ fails (got $got)"
+fi
+
+got=$(let "LINENO = 123"; print $LINENO )
+if	[[ $got != '122' ]]   # TODO: should be 123
+then	err_exit "arithmetic assignment to LINENO fails (got $got)"
+fi
+
+# ======
+# non-base-10 numbers may be negative
+# https://github.com/ksh93/ksh/issues/696
+exp=-20#j12
+integer 20 got=$exp
+[[ $got == "$exp" ]] || err_exit "negative base-20 number (expected '$exp', got '$got')"
+unset got
+
+# ======
+exp=': arithmetic syntax error'
+# when leading 0 is recognised as octal, invalid octal should be an error
+for v in 08 028 089 09 029 098 012345678
+do	got=$(set --letoctal; let "$v" 2>&1)
+	[[ e=$? -eq 1 && $got == *"$exp" ]] || err_exit "invalid leading-zero octal number $v not an error" \
+		"(expected status 1 and match of *'$exp', got status $e and '$got')"
+done
+# only a single 0 should precede x or X for it to be a hexadecimal number
+got=$(eval ': $((00xF))' 2>&1)
+[[ e=$? -eq 1 && $got == *"$exp" ]] || err_exit "extra zero before 0x not an error (expansion)" \
+	"(expected status 1 and match of *'$exp', got status $e and '$got')"
+got=$(let '00xF' 2>&1)
+[[ e=$? -eq 1 && $got == *"$exp" ]] || err_exit "extra zero before 0x not an error (let)" \
+	"(expected status 1 and match of *'$exp', got status $e and '$got')"
+# ksh base specifiers (like 16# for hexadecimal) may not have leading zeros
+got=$(eval ': $((016#F))' 2>&1)
+[[ e=$? -eq 1 && $got == *"$exp" ]] || err_exit "leading zero before 16# not an error (expansion)" \
+	"(expected status 1 and match of *'$exp', got status $e and '$got')"
+got=$(let '016#F' 2>&1)
+[[ e=$? -eq 1 && $got == *"$exp" ]] || err_exit "leading zero before 16# not an error (let)" \
+	"(expected status 1 and match of *'$exp', got status $e and '$got')"
+
+# ======
+# Lexer tests. Unmatched `((' crashed ksh or caused incorrect behaviour until 2024-07-20.
+# https://github.com/ksh93/ksh/issues/764
+exp=": \`(' unmatched"
+got=$( ( ulimit -c 0; set +x; eval '{ (( $(( 1 )); }' ) 2>&1 )
+[[ e=$? -eq 3 && $got == *"$exp" ]] || err_exit "unmatched '((', test 1" \
+	"(expected status 1 and match of *$(printf %q "$exp")," \
+	"got status $e$( ((e>128)) && print -n /SIG && kill -l "$e") and $(printf %q "$got"))"
+got=$( ( ulimit -c 0; set +x; eval 'x=$(( }; echo end' ) 2>&1 )
+[[ e=$? -eq 3 && $got == *"$exp" ]] || err_exit "unmatched '((', test 2" \
+	"(expected status 1 and match of *$(printf %q "$exp")," \
+	"got status $e$( ((e>128)) && print -n /SIG && kill -l "$e") and $(printf %q "$got"))"
+got=$( ( ulimit -c 0; set +x; eval '{ x=$(( }; echo end; }' ) 2>&1 )
+[[ e=$? -eq 3 && $got == *"$exp" ]] || err_exit "unmatched '((', test 3" \
+	"(expected status 1 and match of *$(printf %q "$exp")," \
+	"got status $e$( ((e>128)) && print -n /SIG && kill -l "$e") and $(printf %q "$got"))"
+got=$( ( ulimit -c 0; set +x; eval '(( }; echo end' ) 2>&1 )
+[[ e=$? -eq 3 && $got == *"$exp" ]] || err_exit "unmatched '((', test 4" \
+	"(expected status 1 and match of *$(printf %q "$exp")," \
+	"got status $e$( ((e>128)) && print -n /SIG && kill -l "$e") and $(printf %q "$got"))"
+got=$( ( ulimit -c 0; set +x; eval '{ (( }; echo end; }' ) 2>&1 )
+[[ e=$? -eq 3 && $got == *"$exp" ]] || err_exit "unmatched '((', test 5" \
+	"(expected status 1 and match of *$(printf %q "$exp")," \
+	"got status $e$( ((e>128)) && print -n /SIG && kill -l "$e") and $(printf %q "$got"))"
+
+got=$( ( ulimit -c 0; set +x; eval '{ (( $(( 1 )) )); }' ) 2>&1 )
+[[ e=$? -eq 0 && -z $got ]] || err_exit "matched '((' in compound command" \
+	"(expected status 0 and ''," \
+	"got status $e$( ((e>128)) && print -n /SIG && kill -l "$e") and $(printf %q "$got"))"
+
+# ======
+# On ARM systems, division by negative threw an incorrect "divide by zero" error!
+# https://github.com/ksh93/ksh/issues/770
+got=$(let "10 / -10 == -1 && 10 / -1 == -10 && 10 / -2 == -5" 2>&1) || err_exit "division by negative (got $(printf %q "$got"))"
+# Also, from 2024-01-21 to 2024-07-24, the return value of assigning negative to unsigned int was 0 on ARM
+if	! exp=$(PATH=/opt/ast/bin:$PATH; getconf UINT_MAX 2>/dev/null)
+then	warning "getconf UINT_MAX failed; skipping issue 770 test"
+else	typeset -ui i
+	got=$((i = -1))
+	[[ $i == "$exp" ]] || err_exit "unsigned int wrap-around of -1 (expected '$exp', got '$i')"
+	[[ $got == "$exp" ]] || err_exit "return value of assigning -1 to unsigned int (expected '$exp', got '$got')"
+	unset i
+fi
+
 # ======
 exit $((Errors<125?Errors:125))
