@@ -2,7 +2,7 @@
 #                                                                      #
 #               This software is part of the ast package               #
 #          Copyright (c) 1982-2012 AT&T Intellectual Property          #
-#          Copyright (c) 2020-2022 Contributors to ksh 93u+m           #
+#          Copyright (c) 2020-2023 Contributors to ksh 93u+m           #
 #                      and is licensed under the                       #
 #                 Eclipse Public License, Version 2.0                  #
 #                                                                      #
@@ -269,5 +269,41 @@ ini() { unset arr; typeset -a arr=((10 20) 6 8); }
 unset arr
 unset -f ini
 
+# ======
+# Array slicing
+# https://github.com/ksh93/ksh/issues/605
+unset arr
+exp='1 2 3'
+got=$(arr=(1 2 3); echo "${arr[*]:0:${#arr[@]}}")
+[[ $got == "$exp" ]] || err_exit "array slicing test 1 (expected $(printf %q "$exp"), got $(printf %q "$got"))"
+exp='1 2 3 4'
+got=$(arr=(1 2 3 4 5); echo "${arr[*]:0:${arr[@]:3:1}}")
+[[ $got == "$exp" ]] || err_exit "array slicing test 2 (expected $(printf %q "$exp"), got $(printf %q "$got"))"
+exp='a b c'
+got=$(typeset -a arr=(a b (c d e)); echo ${arr[@]:0:${#arr[@]}})
+[[ $got == "$exp" ]] || err_exit "array slicing test 3 (expected $(printf %q "$exp"), got $(printf %q "$got"))"
+got=$(typeset -a arr=(a (b d e) c); num=${#arr[@]}; echo ${arr[@]:0:num})
+[[ $got == "$exp" ]] || err_exit "array slicing test 4 (expected $(printf %q "$exp"), got $(printf %q "$got"))"
+got=$(typeset -a arr=(a (b d e) c); echo ${arr[@]})
+[[ $got == "$exp" ]] || err_exit "array slicing test 5 (expected $(printf %q "$exp"), got $(printf %q "$got"))"
+got=$(typeset -a arr=(a (b d e) c); echo ${arr[@]:})
+[[ $got == "$exp" ]] || err_exit "array slicing test 6 (expected $(printf %q "$exp"), got $(printf %q "$got"))"
+got=$(typeset -a arr=(a (b d e) c); echo ${arr[@]:0})
+[[ $got == "$exp" ]] || err_exit "array slicing test 7 (expected $(printf %q "$exp"), got $(printf %q "$got"))"
+got=$(typeset -a arr=(a (b d e) c); echo ${arr[@]:0:${#arr[@]}})
+[[ $got == "$exp" ]] || err_exit "array slicing test 8 (expected $(printf %q "$exp"), got $(printf %q "$got"))"
+# below, we must have 'arr=( (a...' and not 'arr=((a...' due to https://github.com/ksh93/ksh/issues/269
+got=$(typeset -a arr=( (a d e) b c); echo ${arr[@]:0:${#arr[@]}})
+[[ $got == "$exp" ]] || err_exit "array slicing test 9 (expected $(printf %q "$exp"), got $(printf %q "$got"))"
+got=$(typeset -A arr=(a (b d e) c); num=${#arr[@]}; echo ${arr[@]:0:num})
+[[ $got == "$exp" ]] || err_exit "array slicing test 10 (expected $(printf %q "$exp"), got $(printf %q "$got"))"
+got=$(typeset -A arr=(a (b d e) c); echo ${arr[@]:0:${#arr[@]}})
+[[ $got == "$exp" ]] || err_exit "array slicing test 11 (expected $(printf %q "$exp"), got $(printf %q "$got"))"
+exp='c d e'
+got=$(typeset -a arr=(a (b d e) c d e); echo ${arr[@]:2:${#arr[@]}-2})
+[[ $got == "$exp" ]] || err_exit "array slicing test 12 (expected $(printf %q "$exp"), got $(printf %q "$got"))"
+got=$(typeset -A arr=(a (b d e) c d e); echo ${arr[@]:2:${#arr[@]}-2})
+[[ $got == "$exp" ]] || err_exit "array slicing test 13 (expected $(printf %q "$exp"), got $(printf %q "$got"))"
+
 # ======
 exit $((Errors<125?Errors:125))
