@@ -2,7 +2,7 @@
 #                                                                      #
 #               This software is part of the ast package               #
 #          Copyright (c) 1982-2012 AT&T Intellectual Property          #
-#          Copyright (c) 2020-2023 Contributors to ksh 93u+m           #
+#          Copyright (c) 2020-2024 Contributors to ksh 93u+m           #
 #                      and is licensed under the                       #
 #                 Eclipse Public License, Version 2.0                  #
 #                                                                      #
@@ -637,5 +637,20 @@ do
 		"(expected $(printf %q "$exp"), got $(printf %q "$got"))"
 done
 
+# ======
+# showme only printed the first redirection in a list
+# https://github.com/ksh93/ksh/issues/753
+got=$(set +x --showme; eval ';true >/dev/null 2>&1 3>&1 4>&3' 2>&1)
+exp=$'+ true\n+ 1> /dev/null 2>& 1 3>& 1 4>& 3'
+[[ $got == "$exp" ]] || err_exit "showme doesn't print redirects properly" \
+	"(expected $(printf %q "$exp"), got $(printf %q "$got"))"
+
+# ======
+# pipefail did not set 9th bit in exit status if a process got signalled
+# https://github.com/ksh93/ksh/discussions/755#discussioncomment-9925394
+got=$(set --pipefail; "$SHELL" -c 'kill -s PIPE $$' | true; echo $?)
+exp=$(( ${ kill -l PIPE; } + 256 ))
+[[ $got == "$exp" ]] || err_exit "status of signalled process in pipe with pipefail (expected $exp, got $got)"
+
 # ======
 exit $((Errors<125?Errors:125))
