@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1985-2012 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2024 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -170,8 +170,7 @@ static void* dtlist(Dt_t* dt, void* obj, int type)
 		goto do_insert;
 	}
 	else if(type&(DT_INSERT|DT_INSTALL|DT_APPEND|DT_ATTACH))
-	{
-		if(!(r = _dtmake(dt, obj, type)) )
+	{	if(!(r = _dtmake(dt, obj, type)) )
 			DTRETURN(obj, NULL);
 		dt->data->size += 1;
 
