@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1985-2011 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2024 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -59,7 +59,7 @@ strptime(const char* s, const char* format, struct tm* ts)
 	t = tmscan(s, &e, format, &f, &t, 0);
 	if (e == (char*)s || *f)
 		return NULL;
-	tmxtm(&tm, tmxclock(&t), NULL, 0);
+	tmxtm(&tm, tmxsns(t,0), NULL, 0);
 	ts->tm_sec = tm.tm_sec;
 	ts->tm_min = tm.tm_min;
 	ts->tm_hour = tm.tm_hour;
