@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1985-2011 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2024 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -125,7 +125,7 @@ static Sfoff_t unseek(Sfio_t* f, Sfoff_t addr, int type, Sfdisc_t* disc)
 /* on close, remove the discipline */
 static int unexcept(Sfio_t* f, int type, void* data, Sfdisc_t* disc)
 {
-	if(type == SF_FINAL || type == SF_DPOP)
+	if(type == SFIO_FINAL || type == SFIO_DPOP)
 		free(disc);
 
 	return 0;
