@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1985-2011 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2024 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -25,6 +25,6 @@
 extern
 Sfulong_t _sfgetu(Sfio_t* f)
 {
-	sfungetc(f, (unsigned char)_SF_(f)->val);
+	sfungetc(f, (unsigned char)_SFIO_(f)->val);
 	return sfgetu(f);
 }
