@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1985-2011 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2024 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -32,22 +32,22 @@ int _sfputl(Sfio_t*	f,	/* write a portable long to this stream */
 	ssize_t	n, p;
 	uchar		c[N_ARRAY];
 
-	if(!f || (f->mode != SF_WRITE && _sfmode(f,SF_WRITE,0) < 0))
+	if(!f || (f->mode != SFIO_WRITE && _sfmode(f,SFIO_WRITE,0) < 0))
 		return -1;
 	SFLOCK(f,0);
 
 	s = ps = &(c[N_ARRAY-1]);
 	if(v < 0)
-	{	/* add 1 to avoid 2-complement problems with -SF_MAXINT */
+	{	/* add 1 to avoid 2-complement problems with -SFIO_MAXINT */
 		v = -(v+1);
-		*s = (uchar)(SFSVALUE(v) | SF_SIGN);
+		*s = (uchar)(SFSVALUE(v) | SFIO_SIGN);
 	}
 	else	*s = (uchar)(SFSVALUE(v));
-	v = (Sfulong_t)v >> SF_SBITS;
+	v = (Sfulong_t)v >> SFIO_SBITS;
 
 	while(v > 0)
-	{	*--s = (uchar)(SFUVALUE(v) | SF_MORE);
-		v = (Sfulong_t)v >> SF_UBITS;
+	{	*--s = (uchar)(SFUVALUE(v) | SFIO_MORE);
+		v = (Sfulong_t)v >> SFIO_UBITS;
 	}
 	n = (ps-s)+1;
 
