@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1985-2012 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2024 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -33,10 +33,10 @@ int sfclose(Sfio_t* f)
 
 	GETLOCAL(f,local);
 
-	if(!(f->mode&SF_INIT) &&
-	   SFMODE(f,local) != (f->mode&SF_RDWR) &&
-	   SFMODE(f,local) != (f->mode&(SF_READ|SF_SYNCED)) &&
-	   _sfmode(f,SF_SYNCED,local) < 0)
+	if(!(f->mode&SFIO_INIT) &&
+	   SFMODE(f,local) != (f->mode&SFIO_RDWR) &&
+	   SFMODE(f,local) != (f->mode&(SFIO_READ|SFIO_SYNCED)) &&
+	   _sfmode(f,SFIO_SYNCED,local) < 0)
 		return -1;
 
 	/* closing a stack of streams */
@@ -56,14 +56,14 @@ int sfclose(Sfio_t* f)
 	if(f->disc == _Sfudisc)	/* closing the ungetc stream */
 		f->disc = NULL;
 	else if(f->file >= 0)	/* sync file pointer */
-	{	f->bits |= SF_ENDING;
+	{	f->bits |= SFIO_ENDING;
 		rv = sfsync(f);
 	}
 
 	SFLOCK(f,0);
 
 	/* raise discipline exceptions */
-	if(f->disc && (ex = SFRAISE(f,local ? SF_NEW : SF_CLOSING,NULL)) != 0)
+	if(f->disc && (ex = SFRAISE(f,local ? SFIO_NEW : SFIO_CLOSING,NULL)) != 0)
 		return ex;
 
 	if(!local && f->pool)
@@ -82,24 +82,24 @@ int sfclose(Sfio_t* f)
 			}
 		}
 		else
-		{	f->mode &= ~SF_LOCK;	/**/ASSERT(_Sfpmove);
+		{	f->mode &= ~SFIO_LOCK;	/**/ASSERT(_Sfpmove);
 			if((*_Sfpmove)(f,-1) < 0)
 			{	SFOPEN(f,0);
 				return -1;
 			}
-			f->mode |= SF_LOCK;
+			f->mode |= SFIO_LOCK;
 		}
 		f->pool = NULL;
 	}
 
-	if(f->data && (!local || (f->flags&SF_STRING) || (f->bits&SF_MMAP) ) )
+	if(f->data && (!local || (f->flags&SFIO_STRING) || (f->bits&SFIO_MMAP) ) )
 	{	/* free buffer */
 #ifdef MAP_TYPE
-		if(f->bits&SF_MMAP)
+		if(f->bits&SFIO_MMAP)
 			SFMUNMAP(f,f->data,f->endb-f->data);
 		else
 #endif
-		if(f->flags&SF_MALLOC)
+		if(f->flags&SFIO_MALLOC)
 			data = f->data;
 
 		f->data = NULL;
@@ -108,8 +108,8 @@ int sfclose(Sfio_t* f)
 
 	/* zap the file descriptor */
 	if(_Sfnotify)
-		(*_Sfnotify)(f, SF_CLOSING, (void*)((long)f->file));
-	if(f->file >= 0 && !(f->flags&SF_STRING))
+		(*_Sfnotify)(f, SFIO_CLOSING, (void*)((long)f->file));
+	if(f->file >= 0 && !(f->flags&SFIO_STRING))
 	{	while(close(f->file) < 0 )
 		{	if(errno == EINTR)
 				errno = 0;
@@ -122,7 +122,7 @@ int sfclose(Sfio_t* f)
 	f->file = -1;
 
 	SFKILL(f);
-	f->flags &= SF_STATIC;
+	f->flags &= SFIO_STATIC;
 	f->here = 0;
 	f->extent = -1;
 	f->endb = f->endr = f->endw = f->next = f->data;
@@ -138,17 +138,17 @@ int sfclose(Sfio_t* f)
 		rv = _sfpclose(f);
 
 	if(!local)
-	{	if(f->disc && (ex = SFRAISE(f,SF_FINAL,NULL)) != 0 )
+	{	if(f->disc && (ex = SFRAISE(f,SFIO_FINAL,NULL)) != 0 )
 		{	rv = ex;
 			goto done;
 		}
 
-		if(!(f->flags&SF_STATIC) )
+		if(!(f->flags&SFIO_STATIC) )
 			free(f);
 		else
 		{	f->disc = NULL;
 			f->stdio = NULL;
-			f->mode = SF_AVAIL;
+			f->mode = SFIO_AVAIL;
 		}
 	}
 
