@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1985-2012 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2024 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -38,7 +38,7 @@ static char*	Version = "\n@(#)$Id: sfio (AT&T Labs - Research) 2009-09-15 $\0\n"
 **		09/09/1999 (thread-safe)
 **		02/01/2001 (adaptive buffering)
 **		05/31/2002 (multi-byte handling in sfvprintf/vscanf)
-**		09/06/2002 (SF_IOINTR flag)
+**		09/06/2002 (SFIO_IOINTR flag)
 **		11/15/2002 (%#c for sfvprintf)
 **		05/31/2003 (sfsetbuf(f,f,align_size) to set alignment for data)
 **			   (%I1d is fixed to handle "signed char" correctly)
@@ -76,19 +76,19 @@ static void _sfcleanup(void)
 			SFLOCK(f,0);
 
 			/* let application know that we are leaving */
-			(void)SFRAISE(f, SF_ATEXIT, NULL);
+			(void)SFRAISE(f, SFIO_ATEXIT, NULL);
 
-			if(f->flags&SF_STRING)
+			if(f->flags&SFIO_STRING)
 				continue;
 
 			/* from now on, write streams are unbuffered */
-			pool = f->mode&SF_POOL;
-			f->mode &= ~SF_POOL;
-			if((f->flags&SF_WRITE) && !(f->mode&SF_WRITE))
-				(void)_sfmode(f,SF_WRITE,1);
+			pool = f->mode&SFIO_POOL;
+			f->mode &= ~SFIO_POOL;
+			if((f->flags&SFIO_WRITE) && !(f->mode&SFIO_WRITE))
+				(void)_sfmode(f,SFIO_WRITE,1);
 			if(f->data &&
-			   ((f->bits&SF_MMAP) ||
-			    ((f->mode&SF_WRITE) && f->next == f->data) ) )
+			   ((f->bits&SFIO_MMAP) ||
+			    ((f->mode&SFIO_WRITE) && f->next == f->data) ) )
 				(void)SFSETBUF(f,NULL,0);
 			f->mode |= pool;
 
@@ -151,7 +151,7 @@ Sfrsrv_t* _sfrsrv(Sfio_t* f, ssize_t size)
 	Sfrsrv_t	*rsrv, *rs;
 
 	/* make buffer if nothing yet */
-	size = ((size + SF_GRAIN-1)/SF_GRAIN)*SF_GRAIN;
+	size = ((size + SFIO_GRAIN-1)/SFIO_GRAIN)*SFIO_GRAIN;
 	if(!(rsrv = f->rsrv) || size > rsrv->size)
 	{	if(!(rs = (Sfrsrv_t*)malloc(size+sizeof(Sfrsrv_t))))
 			size = -1;
@@ -187,7 +187,7 @@ int _sfpopen(Sfio_t* f, int fd, int pid, int stdio)	/* stdio popen() does not re
 	p->size = p->ndata = 0;
 	p->rdata = NULL;
 	p->file = fd;
-	p->sigp = (!stdio && pid >= 0 && (f->flags&SF_WRITE)) ? 1 : 0;
+	p->sigp = (!stdio && pid >= 0 && (f->flags&SFIO_WRITE)) ? 1 : 0;
 
 	/* protect from broken pipe signal */
 	if(p->sigp)
@@ -250,12 +250,12 @@ static int _sfpmode(Sfio_t* f, int type)
 	if(!(p = f->proc) )
 		return -1;
 
-	if(type == SF_WRITE)
+	if(type == SFIO_WRITE)
 	{	/* save unread data */
 		p->ndata = f->endb-f->next;
 		if(p->ndata > p->size)
 		{	if(p->rdata)
-				free((char*)p->rdata);
+				free(p->rdata);
 			if((p->rdata = (uchar*)malloc(p->ndata)) )
 				p->size = p->ndata;
 			else
@@ -297,25 +297,25 @@ int _sfmode(Sfio_t*	f,	/* change r/w mode and sync file pointer for this stream
 	int	rv = 0;
 
 
-	if(wanted&SF_SYNCED) /* for (SF_SYNCED|SF_READ) stream, just junk data */
-	{	wanted &= ~SF_SYNCED;
-		if((f->mode&(SF_SYNCED|SF_READ)) == (SF_SYNCED|SF_READ) )
+	if(wanted&SFIO_SYNCED) /* for (SFIO_SYNCED|SFIO_READ) stream, just junk data */
+	{	wanted &= ~SFIO_SYNCED;
+		if((f->mode&(SFIO_SYNCED|SFIO_READ)) == (SFIO_SYNCED|SFIO_READ) )
 		{	f->next = f->endb = f->endr = f->data;
-			f->mode &= ~SF_SYNCED;
+			f->mode &= ~SFIO_SYNCED;
 		}
 	}
 
-	if((!local && SFFROZEN(f)) || (!(f->flags&SF_STRING) && f->file < 0))
+	if((!local && SFFROZEN(f)) || (!(f->flags&SFIO_STRING) && f->file < 0))
 	{	if(local || !f->disc || !f->disc->exceptf)
 		{	local = 1;
 			goto err_notify;
 		}
 
 		for(;;)
-		{	if((rv = (*f->disc->exceptf)(f,SF_LOCKED,0,f->disc)) < 0)
+		{	if((rv = (*f->disc->exceptf)(f,SFIO_LOCKED,0,f->disc)) < 0)
 				return rv;
 			if((!local && SFFROZEN(f)) ||
-			   (!(f->flags&SF_STRING) && f->file < 0) )
+			   (!(f->flags&SFIO_STRING) && f->file < 0) )
 			{	if(rv == 0)
 				{	local = 1;
 					goto err_notify;
@@ -326,16 +326,16 @@ int _sfmode(Sfio_t*	f,	/* change r/w mode and sync file pointer for this stream
 		}
 	}
 
-	if(f->mode&SF_GETR)
-	{	f->mode &= ~SF_GETR;
+	if(f->mode&SFIO_GETR)
+	{	f->mode &= ~SFIO_GETR;
 #ifdef MAP_TYPE
-		if(f->bits&SF_MMAP)
+		if(f->bits&SFIO_MMAP)
 		{
 			if (!++f->ngetr)
 				f->tiny[0]++;
-			if(((f->tiny[0]<<8)|f->ngetr) >= (4*SF_NMAP) )
+			if(((f->tiny[0]<<8)|f->ngetr) >= (4*SFIO_NMAP) )
 			{	/* turn off mmap to avoid page faulting */
-				sfsetbuf(f,f->tiny,(size_t)SF_UNBOUND);
+				sfsetbuf(f,f->tiny,(size_t)SFIO_UNBOUND);
 				f->ngetr = f->tiny[0] = 0;
 			}
 		}
@@ -346,29 +346,29 @@ int _sfmode(Sfio_t*	f,	/* change r/w mode and sync file pointer for this stream
 		}
 	}
 
-	if(f->mode&SF_STDIO) /* synchronizing with stdio pointers */
+	if(f->mode&SFIO_STDIO) /* synchronizing with stdio pointers */
 		(*_Sfstdsync)(f);
 
-	if(f->disc == _Sfudisc && wanted == SF_WRITE &&
+	if(f->disc == _Sfudisc && wanted == SFIO_WRITE &&
 	   sfclose((*_Sfstack)(f,NULL)) < 0 )
 	{	local = 1;
 		goto err_notify;
 	}
 
-	if(f->mode&SF_POOL)
+	if(f->mode&SFIO_POOL)
 	{	/* move to head of pool */
 		if(f == f->pool->sf[0] || (*_Sfpmove)(f,0) < 0 )
 		{	local = 1;
 			goto err_notify;
 		}
-		f->mode &= ~SF_POOL;
+		f->mode &= ~SFIO_POOL;
 	}
 
 	SFLOCK(f,local);
 
 	/* buffer initialization */
-	wanted &= SF_RDWR;
-	if(f->mode&SF_INIT)
+	wanted &= SFIO_RDWR;
+	if(f->mode&SFIO_INIT)
 	{	
 		if(!f->pool && _sfsetpool(f) < 0)
 		{	rv = -1;
@@ -378,24 +378,24 @@ int _sfmode(Sfio_t*	f,	/* change r/w mode and sync file pointer for this stream
 		if(wanted == 0)
 			goto done;
 
-		if(wanted != (int)(f->mode&SF_RDWR) && !(f->flags&wanted) )
+		if(wanted != (int)(f->mode&SFIO_RDWR) && !(f->flags&wanted) )
 			goto err_notify;
 
-		if((f->flags&SF_STRING) && f->size >= 0 && f->data)
-		{	f->mode &= ~SF_INIT;
-			f->extent = ((f->flags&SF_READ) || (f->bits&SF_BOTH)) ?
+		if((f->flags&SFIO_STRING) && f->size >= 0 && f->data)
+		{	f->mode &= ~SFIO_INIT;
+			f->extent = ((f->flags&SFIO_READ) || (f->bits&SFIO_BOTH)) ?
 					f->size : 0;
 			f->here = 0;
 			f->endb = f->data + f->size;
 			f->next = f->endr = f->endw = f->data;
-			if(f->mode&SF_READ)
+			if(f->mode&SFIO_READ)
 				f->endr = f->endb;
 			else	f->endw = f->endb;
 		}
 		else
 		{	n = f->flags;
 			(void)SFSETBUF(f,f->data,f->size);
-			f->flags |= (n&SF_MALLOC);
+			f->flags |= (n&SFIO_MALLOC);
 		}
 	}
 
@@ -404,15 +404,15 @@ int _sfmode(Sfio_t*	f,	/* change r/w mode and sync file pointer for this stream
 
 	switch(SFMODE(f,1))
 	{
-	case SF_WRITE: /* switching to SF_READ */
-		if(wanted == 0 || wanted == SF_WRITE)
+	case SFIO_WRITE: /* switching to SFIO_READ */
+		if(wanted == 0 || wanted == SFIO_WRITE)
 			break;
-		if(!(f->flags&SF_READ) )
+		if(!(f->flags&SFIO_READ) )
 			goto err_notify;
-		else if(f->flags&SF_STRING)
+		else if(f->flags&SFIO_STRING)
 		{	SFSTRSIZE(f);
 			f->endb = f->data+f->extent;
-			f->mode = SF_READ;
+			f->mode = SFIO_READ;
 			break;
 		}
 
@@ -426,7 +426,7 @@ int _sfmode(Sfio_t*	f,	/* change r/w mode and sync file pointer for this stream
 			f->size = sizeof(f->tiny);
 		}
 		f->next = f->endr = f->endw = f->endb = f->data;
-		f->mode = SF_READ|SF_LOCK;
+		f->mode = SFIO_READ|SFIO_LOCK;
 
 		/* restore saved read data for coprocess */
 		if(f->proc && _sfpmode(f,wanted) < 0)
@@ -434,17 +434,17 @@ int _sfmode(Sfio_t*	f,	/* change r/w mode and sync file pointer for this stream
 
 		break;
 
-	case (SF_READ|SF_SYNCED): /* a previously sync-ed read stream */
-		if(wanted != SF_WRITE)
+	case (SFIO_READ|SFIO_SYNCED): /* a previously sync-ed read stream */
+		if(wanted != SFIO_WRITE)
 		{	/* just reset the pointers */
-			f->mode = SF_READ|SF_LOCK;
+			f->mode = SFIO_READ|SFIO_LOCK;
 
 			/* see if must go with new physical location */
-			if((f->flags&(SF_SHARE|SF_PUBLIC)) == (SF_SHARE|SF_PUBLIC) &&
+			if((f->flags&(SFIO_SHARE|SFIO_PUBLIC)) == (SFIO_SHARE|SFIO_PUBLIC) &&
 			   (addr = SFSK(f,0,SEEK_CUR,f->disc)) != f->here)
 			{
 #ifdef MAP_TYPE
-				if((f->bits&SF_MMAP) && f->data)
+				if((f->bits&SFIO_MMAP) && f->data)
 				{	SFMUNMAP(f,f->data,f->endb-f->data);
 					f->data = NULL;
 				}
@@ -463,14 +463,14 @@ int _sfmode(Sfio_t*	f,	/* change r/w mode and sync file pointer for this stream
 		}
 		/* FALLTHROUGH */
 
-	case SF_READ: /* switching to SF_WRITE */
-		if(wanted != SF_WRITE)
+	case SFIO_READ: /* switching to SFIO_WRITE */
+		if(wanted != SFIO_WRITE)
 			break;
-		else if(!(f->flags&SF_WRITE))
+		else if(!(f->flags&SFIO_WRITE))
 			goto err_notify;
-		else if(f->flags&SF_STRING)
+		else if(f->flags&SFIO_STRING)
 		{	f->endb = f->data+f->size;
-			f->mode = SF_WRITE|SF_LOCK;
+			f->mode = SFIO_WRITE|SFIO_LOCK;
 			break;
 		}
 
@@ -479,9 +479,9 @@ int _sfmode(Sfio_t*	f,	/* change r/w mode and sync file pointer for this stream
 			goto err_notify;
 
 		/* reset buffer and seek pointer */
-		if(!(f->mode&SF_SYNCED) )
+		if(!(f->mode&SFIO_SYNCED) )
 		{	intptr_t nn = f->endb - f->next;
-			if(f->extent >= 0 && (nn > 0 || (f->data && (f->bits&SF_MMAP))) )
+			if(f->extent >= 0 && (nn > 0 || (f->data && (f->bits&SFIO_MMAP))) )
 			{	/* reset file pointer */
 				addr = f->here - nn;
 				if(SFSK(f,addr,SEEK_SET,f->disc) < 0)
@@ -490,12 +490,12 @@ int _sfmode(Sfio_t*	f,	/* change r/w mode and sync file pointer for this stream
 			}
 		}
 
-		f->mode = SF_WRITE|SF_LOCK;
+		f->mode = SFIO_WRITE|SFIO_LOCK;
 #ifdef MAP_TYPE
-		if(f->bits&SF_MMAP)
+		if(f->bits&SFIO_MMAP)
 		{	if(f->data)
 				SFMUNMAP(f,f->data,f->endb-f->data);
-			(void)SFSETBUF(f,f->tiny,(size_t)SF_UNBOUND);
+			(void)SFSETBUF(f,f->tiny,(size_t)SFIO_UNBOUND);
 		}
 #endif
 		if(f->data == f->tiny)
@@ -508,11 +508,11 @@ int _sfmode(Sfio_t*	f,	/* change r/w mode and sync file pointer for this stream
 
 	default: /* unknown case */
 	err_notify:
-		if((wanted &= SF_RDWR) == 0 && (wanted = f->flags&SF_RDWR) == SF_RDWR)
-			wanted = SF_READ;
+		if((wanted &= SFIO_RDWR) == 0 && (wanted = f->flags&SFIO_RDWR) == SFIO_RDWR)
+			wanted = SFIO_READ;
 
 		/* set errno for operations that access wrong stream type */
-		if(wanted != (f->mode&SF_RDWR) && f->file >= 0)
+		if(wanted != (f->mode&SFIO_RDWR) && f->file >= 0)
 			errno = EBADF;
 
 		if(_Sfnotify) /* notify application of the error */
