@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1985-2011 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2024 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -28,24 +28,24 @@ int sfpurge(Sfio_t* f)
 {
 	int	mode;
 
-	if(!f || (mode = f->mode&SF_RDWR) != (int)f->mode && _sfmode(f,mode|SF_SYNCED,0) < 0)
+	if(!f || (mode = f->mode&SFIO_RDWR) != (int)f->mode && _sfmode(f,mode|SFIO_SYNCED,0) < 0)
 		return -1;
 
-	if((f->flags&SF_IOCHECK) && f->disc && f->disc->exceptf)
-		(void)(*f->disc->exceptf)(f,SF_PURGE,(void*)((int)1),f->disc);
+	if((f->flags&SFIO_IOCHECK) && f->disc && f->disc->exceptf)
+		(void)(*f->disc->exceptf)(f,SFIO_PURGE,(void*)((int)1),f->disc);
 
 	if(f->disc == _Sfudisc)
 		(void)sfclose((*_Sfstack)(f,NULL));
 
 	/* cannot purge read string streams */
-	if((f->flags&SF_STRING) && (f->mode&SF_READ) )
+	if((f->flags&SFIO_STRING) && (f->mode&SFIO_READ) )
 		goto done;
 
 	SFLOCK(f,0);
 
 	/* if memory map must be a read stream, pretend data is gone */
 #ifdef MAP_TYPE
-	if(f->bits&SF_MMAP)
+	if(f->bits&SFIO_MMAP)
 	{	f->here -= f->endb - f->next;
 		if(f->data)
 		{	SFMUNMAP(f,f->data,f->endb-f->data);
@@ -56,20 +56,20 @@ int sfpurge(Sfio_t* f)
 	}
 #endif
 
-	switch(f->mode&~SF_LOCK)
+	switch(f->mode&~SFIO_LOCK)
 	{
 	default :
 		SFOPEN(f,0);
 		return -1;
-	case SF_WRITE :
+	case SFIO_WRITE :
 		f->next = f->data;
-		if(!f->proc || !(f->flags&SF_READ) || !(f->mode&SF_WRITE) )
+		if(!f->proc || !(f->flags&SFIO_READ) || !(f->mode&SFIO_WRITE) )
 			break;
 
 		/* 2-way pipe, must clear read buffer */
-		(void)_sfmode(f,SF_READ,1);
+		(void)_sfmode(f,SFIO_READ,1);
 		/* FALLTHROUGH */
-	case SF_READ:
+	case SFIO_READ:
 		if(f->extent >= 0 && f->endb > f->next)
 		{	f->here -= f->endb-f->next;
 			(void)SFSK(f,f->here,SEEK_SET,f->disc);
@@ -81,8 +81,8 @@ int sfpurge(Sfio_t* f)
 	SFOPEN(f,0);
 
 done:
-	if((f->flags&SF_IOCHECK) && f->disc && f->disc->exceptf)
-		(void)(*f->disc->exceptf)(f,SF_PURGE,(void*)((int)0),f->disc);
+	if((f->flags&SFIO_IOCHECK) && f->disc && f->disc->exceptf)
+		(void)(*f->disc->exceptf)(f,SFIO_PURGE,(void*)((int)0),f->disc);
 
 	return 0;
 }
