@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1985-2011 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2024 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -37,7 +37,7 @@ static void _sfwrsync(void)
 			continue;
 		f = p->sf[0];
 		if(!SFFROZEN(f) && f->next > f->data &&
-		   (f->mode&SF_WRITE) && f->extent < 0 )
+		   (f->mode&SFIO_WRITE) && f->extent < 0 )
 			(void)_sfflsbuf(f,-1);
 	}
 
@@ -46,7 +46,7 @@ static void _sfwrsync(void)
 	{	f = _Sfpool.sf[n];
 
 		if(!SFFROZEN(f) && f->next > f->data &&
-		   (f->mode&SF_WRITE) && f->extent < 0 )
+		   (f->mode&SFIO_WRITE) && f->extent < 0 )
 			(void)_sfflsbuf(f,-1);
 	}
 }
@@ -61,25 +61,25 @@ ssize_t sfrd(Sfio_t* f, void* buf, size_t n, Sfdisc_t* disc)
 		return -1;
 
 	GETLOCAL(f,local);
-	if((rcrv = f->mode & (SF_RC|SF_RV)) )
-		f->mode &= ~(SF_RC|SF_RV);
-	f->bits &= ~SF_JUSTSEEK;
+	if((rcrv = f->mode & (SFIO_RC|SFIO_RV)) )
+		f->mode &= ~(SFIO_RC|SFIO_RV);
+	f->bits &= ~SFIO_JUSTSEEK;
 
-	if(f->mode&SF_PKRD)
+	if(f->mode&SFIO_PKRD)
 		return -1;
 
-	if(!local && !(f->bits&SF_DCDOWN)) /* an external user's call */
-	{	if(f->mode != SF_READ && _sfmode(f,SF_READ,0) < 0)
+	if(!local && !(f->bits&SFIO_DCDOWN)) /* an external user's call */
+	{	if(f->mode != SFIO_READ && _sfmode(f,SFIO_READ,0) < 0)
 			return -1;
 		if(f->next < f->endb)
 		{	if(SFSYNC(f) < 0)
 				return -1;
-			if((f->mode&(SF_SYNCED|SF_READ)) == (SF_SYNCED|SF_READ) )
+			if((f->mode&(SFIO_SYNCED|SFIO_READ)) == (SFIO_SYNCED|SFIO_READ) )
 			{	f->endb = f->next = f->endr = f->data;
-				f->mode &= ~SF_SYNCED;
+				f->mode &= ~SFIO_SYNCED;
 			}
 #ifdef MAP_TYPE
-			if((f->bits&SF_MMAP) && f->data)
+			if((f->bits&SFIO_MMAP) && f->data)
 			{	SFMUNMAP(f, f->data, f->endb-f->data);
 				f->data = NULL;
 			}
@@ -90,14 +90,14 @@ ssize_t sfrd(Sfio_t* f, void* buf, size_t n, Sfdisc_t* disc)
 
 	for(dosync = 0;;)
 	{	/* stream locked by sfsetfd() */
-		if(!(f->flags&SF_STRING) && f->file < 0)
+		if(!(f->flags&SFIO_STRING) && f->file < 0)
 			return 0;
 
-		f->flags &= ~(SF_EOF|SF_ERROR);
+		f->flags &= ~(SFIO_EOF|SFIO_ERROR);
 
 		dc = disc;
-		if(f->flags&SF_STRING)
-		{	if((r = (f->data+f->extent) - f->next) < 0)
+		if(f->flags&SFIO_STRING)
+		{	if(!f->data || (r = (f->data+f->extent) - f->next) < 0)
 				r = 0;
 			if(r <= 0)
 				goto do_except;
@@ -106,20 +106,20 @@ ssize_t sfrd(Sfio_t* f, void* buf, size_t n, Sfdisc_t* disc)
 
 		/* warn that a read is about to happen */
 		SFDISC(f,dc,readf);
-		if(dc && dc->exceptf && (f->flags&SF_IOCHECK) )
+		if(dc && dc->exceptf && (f->flags&SFIO_IOCHECK) )
 		{	int	rv;
 			if(local)
 				SETLOCAL(f);
-			if((rv = _sfexcept(f,SF_READ,n,dc)) > 0)
+			if((rv = _sfexcept(f,SFIO_READ,n,dc)) > 0)
 				n = rv;
 			else if(rv < 0)
-			{	f->flags |= SF_ERROR;
+			{	f->flags |= SFIO_ERROR;
 				return (ssize_t)rv;
 			}
 		}
 
 #ifdef MAP_TYPE
-		if(f->bits&SF_MMAP)
+		if(f->bits&SFIO_MMAP)
 		{	ssize_t	a, round;
 			struct stat	st;
 
@@ -130,13 +130,13 @@ ssize_t sfrd(Sfio_t* f, void* buf, size_t n, Sfdisc_t* disc)
 			}
 
 			/* actual seek location */
-			if((f->flags&(SF_SHARE|SF_PUBLIC)) == (SF_SHARE|SF_PUBLIC) &&
+			if((f->flags&(SFIO_SHARE|SFIO_PUBLIC)) == (SFIO_SHARE|SFIO_PUBLIC) &&
 			   (r = SFSK(f,0,SEEK_CUR,dc)) != f->here)
 				f->here = r;
 			else	f->here -= f->endb-f->next;
 
 			/* before mapping, make sure we have data to map */
-			if((f->flags&SF_SHARE) || (size_t)(r = f->extent-f->here) < n)
+			if((f->flags&SFIO_SHARE) || (size_t)(r = f->extent-f->here) < n)
 			{	if((r = fstat(f->file,&st)) < 0)
 					goto do_except;
 				if((r = (f->extent = st.st_size) - f->here) <= 0 )
@@ -167,14 +167,14 @@ ssize_t sfrd(Sfio_t* f, void* buf, size_t n, Sfdisc_t* disc)
 					break;
 				else
 				{	f->data = NULL;
-					if((r >>= 1) < (_Sfpage*SF_NMAP) ||
+					if((r >>= 1) < (_Sfpage*SFIO_NMAP) ||
 					   (errno != EAGAIN && errno != ENOMEM) )
 						break;
 				}
 			}
 
 			if(f->data)
-			{	if(f->bits&SF_SEQUENTIAL)
+			{	if(f->bits&SFIO_SEQUENTIAL)
 					SFMMSEQON(f,f->data,r);
 				f->next = f->data+a;
 				f->endr = f->endb = f->data+r;
@@ -202,7 +202,7 @@ ssize_t sfrd(Sfio_t* f, void* buf, size_t n, Sfdisc_t* disc)
 				(void)SFSK(f,f->here,SEEK_SET,dc);
 
 				/* make a buffer */
-				(void)SFSETBUF(f,f->tiny,(size_t)SF_UNBOUND);
+				(void)SFSETBUF(f,f->tiny,(size_t)SFIO_UNBOUND);
 
 				if(!buf)
 				{	buf = f->data;
@@ -219,8 +219,8 @@ ssize_t sfrd(Sfio_t* f, void* buf, size_t n, Sfdisc_t* disc)
 		}
 
 		/* make sure file pointer is right */
-		if(f->extent >= 0 && (f->flags&SF_SHARE) )
-		{	if(!(f->flags&SF_PUBLIC) )
+		if(f->extent >= 0 && (f->flags&SFIO_SHARE) )
+		{	if(!(f->flags&SFIO_PUBLIC) )
 				f->here = SFSK(f,f->here,SEEK_SET,dc);
 			else	f->here = SFSK(f,0,SEEK_CUR,dc);
 		}
@@ -229,12 +229,12 @@ ssize_t sfrd(Sfio_t* f, void* buf, size_t n, Sfdisc_t* disc)
 		errno = 0;
 
 		if(dc && dc->readf)
-		{	int	share = f->flags&SF_SHARE;
+		{	int	share = f->flags&SFIO_SHARE;
 
 			if(rcrv) /* pass on rcrv for possible continuations */
 				f->mode |= rcrv;
 				/* tell readf that no peeking necessary */
-			else	f->flags &= ~SF_SHARE;
+			else	f->flags &= ~SFIO_SHARE;
 
 			SFDCRD(f,buf,n,dc,r);
 
@@ -245,15 +245,15 @@ ssize_t sfrd(Sfio_t* f, void* buf, size_t n, Sfdisc_t* disc)
 		}
 		else if(SFISNULL(f))
 			r = 0;
-		else if(f->extent < 0 && (f->flags&SF_SHARE) && rcrv)
+		else if(f->extent < 0 && (f->flags&SFIO_SHARE) && rcrv)
 		{	/* try peek read */
 			r = sfpkrd(f->file, (char*)buf, n,
-				    (rcrv&SF_RC) ? (int)f->getr : -1,
-				    -1L, (rcrv&SF_RV) ? 1 : 0);
+				    (rcrv&SFIO_RC) ? (int)f->getr : -1,
+				    -1L, (rcrv&SFIO_RV) ? 1 : 0);
 			if(r > 0)
-			{	if(rcrv&SF_RV)
-					f->mode |= SF_PKRD;
-				else	f->mode |= SF_RC;
+			{	if(rcrv&SFIO_RV)
+					f->mode |= SFIO_PKRD;
+				else	f->mode |= SFIO_RC;
 			}
 		}
 		else	r = read(f->file,buf,n);
@@ -262,8 +262,8 @@ ssize_t sfrd(Sfio_t* f, void* buf, size_t n, Sfdisc_t* disc)
 			errno = oerrno;
 
 		if(r > 0 )
-		{	if(!(f->bits&SF_DCDOWN) )	/* not a continuation call */
-			{	if(!(f->mode&SF_PKRD) )
+		{	if(!(f->bits&SFIO_DCDOWN) )	/* not a continuation call */
+			{	if(!(f->mode&SFIO_PKRD) )
 				{	f->here += r;
 					if(f->extent >= 0 && f->extent < f->here)
 						f->extent = f->here;
@@ -279,18 +279,18 @@ ssize_t sfrd(Sfio_t* f, void* buf, size_t n, Sfdisc_t* disc)
 	do_except:
 		if(local)
 			SETLOCAL(f);
-		switch(_sfexcept(f,SF_READ,(ssize_t)r,dc))
+		switch(_sfexcept(f,SFIO_READ,(ssize_t)r,dc))
 		{
-		case SF_ECONT :
+		case SFIO_ECONT :
 			goto do_continue;
-		case SF_EDONE :
+		case SFIO_EDONE :
 			n = local ? 0 : (ssize_t)r;
 			return n;
-		case SF_EDISC :
-			if(!local && !(f->flags&SF_STRING))
+		case SFIO_EDISC :
+			if(!local && !(f->flags&SFIO_STRING))
 				goto do_continue;
 			/* FALLTHROUGH */
-		case SF_ESTACK :
+		case SFIO_ESTACK :
 			return -1;
 		}
 
