@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1985-2011 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2024 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -19,7 +19,7 @@
 ***********************************************************************/
 #include	"sfhdr.h"
 
-/*	Push back one byte to a given SF_READ stream
+/*	Push back one byte to a given SFIO_READ stream
 **
 **	Written by Kiem-Phong Vo.
 */
@@ -32,7 +32,7 @@ static int _uexcept(Sfio_t* f, int type, void* val, Sfdisc_t* disc)
 		return -1;
 
 	/* close the unget stream */
-	if(type != SF_CLOSING)
+	if(type != SFIO_CLOSING)
 		(void)sfclose((*_Sfstack)(f,NULL));
 
 	return 1;
@@ -43,7 +43,7 @@ int sfungetc(Sfio_t*	f,	/* push back one byte to this stream */
 {
 	Sfio_t*	uf;
 
-	if(!f || c < 0 || (f->mode != SF_READ && _sfmode(f,SF_READ,0) < 0))
+	if(!f || c < 0 || (f->mode != SFIO_READ && _sfmode(f,SFIO_READ,0) < 0))
 		return -1;
 	SFLOCK(f,0);
 
@@ -55,8 +55,8 @@ int sfungetc(Sfio_t*	f,	/* push back one byte to this stream */
 
 	/* make a string stream for unget characters */
 	if(f->disc != _Sfudisc)
-	{	if(!(uf = sfnew(NULL,NULL,(size_t)SF_UNBOUND,
-				-1,SF_STRING|SF_READ)))
+	{	if(!(uf = sfnew(NULL,NULL,(size_t)SFIO_UNBOUND,
+				-1,SFIO_STRING|SFIO_READ)))
 		{	c = -1;
 			goto done;
 		}
@@ -74,7 +74,7 @@ int sfungetc(Sfio_t*	f,	/* push back one byte to this stream */
 		{	c = -1;
 			goto done;
 		}
-		f->flags |= SF_MALLOC;
+		f->flags |= SFIO_MALLOC;
 		if(f->data)
 			memcpy((char*)(data+16),(char*)f->data,f->size);
 		f->size += 16;
