@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1985-2012 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2022 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2024 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -15,6 +15,8 @@
 *                   Phong Vo <kpv@research.att.com>                    *
 *                  Martijn Dekker <martijn@inlv.org>                   *
 *            Johnothan King <johnothanking@protonmail.com>             *
+*                      Phi <phi.debian@gmail.com>                      *
+*         hyenias <58673227+hyenias@users.noreply.github.com>          *
 *                                                                      *
 ***********************************************************************/
 #include	"sfhdr.h"
@@ -28,6 +30,7 @@
 **
 **	Written by Kiem-Phong Vo.
 */
+
 #define HIGHBITI	(~((~((uint)0)) >> 1))
 #define HIGHBITL	(~((~((Sfulong_t)0)) >> 1))
 
@@ -35,20 +38,7 @@
 
 #define FPRECIS		6	/* default precision for floats 	*/
 
-#if _PACKAGE_ast
 #include <ccode.h>
-#else
-/* characters when using EBCDIC or ASCII */
-#if _chr_ebcdic
-#define CC_vt			013	/* vertical tab	*/
-#define CC_esc			047	/* escape	*/
-#define CC_bel			057	/* bell		*/
-#else
-#define CC_vt			013	/* vertical tab	*/
-#define CC_esc			033	/* escape	*/
-#define CC_bel			007	/* bell		*/
-#endif /* _chr_ebcdic */
-#endif /* _PACKAGE_ast */
 
 static int chr2str(char* buf, int v)
 {
@@ -92,9 +82,7 @@ int sfvprintf(Sfio_t*		f,		/* file to print to	*/
 	Sflong_t	lv;
 	char		*sp, *ssp, *endsp, *ep, *endep;
 	int		dot, width, precis, sign, decpt;
-#if _PACKAGE_ast
 	int		scale;
-#endif
 	ssize_t		size;
 	Sfdouble_t	dval;
 	void*		valp;
@@ -110,9 +98,11 @@ int sfvprintf(Sfio_t*		f,		/* file to print to	*/
 	va_list		oargs;		/* original arg list		*/
 	Fmtpos_t*	fp;		/* arg position list		*/
 	int		argp, argn;	/* arg position and number	*/
+	int		nargs;		/* the argv[] index of the last seen sequential % format (% or *) */
+	int		xargs;		/* highest (max) argv[] index see in an indexed format (%x$ *x$)  */
 
 #define SLACK		1024
-	char		buf[SF_MAXDIGITS+SLACK], tmp[SF_MAXDIGITS+1], data[SF_GRAIN];
+	char		buf[SFIO_MAXDIGITS+SLACK], tmp[SFIO_MAXDIGITS+1], data[SFIO_GRAIN];
 	int		decimal = 0, thousand = 0;
 
 #if _has_multibyte
@@ -131,7 +121,7 @@ int sfvprintf(Sfio_t*		f,		/* file to print to	*/
 #define SMnputc(f,c,n)	{ if((o = SFNPUTC(f,c,n)) > 0 ) n_output += 1; \
 			  if(o != n)	{ SFBUF(f); goto done; } \
 			}
-#define SMwrite(f,s,n)	{ if((o = SFWRITE(f,(void*)s,n)) > 0 ) n_output += o; \
+#define SMwrite(f,s,n)	{ if((o = SFWRITE(f,s,n)) > 0 ) n_output += o; \
 			  if(o != n)	{ SFBUF(f); goto done; } \
 			}
 #if _sffmt_small /* these macros are made smaller at some performance cost */
@@ -164,26 +154,28 @@ int sfvprintf(Sfio_t*		f,		/* file to print to	*/
 		return -1;
 
 	/* make sure stream is in write mode and buffer is not NULL */
-	if(f->mode != SF_WRITE && _sfmode(f,SF_WRITE,0) < 0)
+	if(f->mode != SFIO_WRITE && _sfmode(f,SFIO_WRITE,0) < 0)
 		return -1;
 
 	SFLOCK(f,0);
 
-	if(!f->data && !(f->flags&SF_STRING))
+	if(!f->data && !(f->flags&SFIO_STRING))
 	{	f->data = f->next = (uchar*)data;
 		f->endb = f->data+sizeof(data);
 	}
 	SFINIT(f);
 
-	tls[1] = NIL(char*);
+	tls[1] = NULL;
 
-	fmstk = NIL(Fmt_t*);
-	ft = NIL(Sffmt_t*);
+	fmstk = NULL;
+	ft = NULL;
 
 	oform = (char*)form;
 	va_copy(oargs,args);
 	argn = -1;
-	fp = NIL(Fmtpos_t*);
+	fp = NULL;
+
+	nargs = xargs = -1;
 
 loop_fmt :
 	SFMBCLR(&fmbs); /* clear multibyte states to parse the format string */
@@ -204,16 +196,13 @@ loop_fmt :
 		else	form += 1;
 
 		flags = 0;
-#if _PACKAGE_ast
 		scale = 0;
-#endif
 		size = width = precis = base = n_s = argp = -1;
 		ssp = _Sfdigits;
-		endep = ep = NIL(char*);
+		endep = ep = NULL;
 		endsp = sp = buf+(sizeof(buf)-1);
-		t_str = NIL(char*);
+		t_str = NULL;
 		n_str = dot = 0;
-
 	loop_flags:	/* LOOP FOR \0, %, FLAGS, WIDTH, PRECISION, BASE, TYPE */
 		switch((fmt = *form++) )
 		{
@@ -223,6 +212,9 @@ loop_fmt :
 		case '%' :
 			SFputc(f,'%');
 			continue;
+		case 'Z' :
+			SFputc(f,0);
+			continue;
 
 		case LEFTP : /* get the type enclosed in balanced parens */
 			t_str = (char*)form;
@@ -231,7 +223,7 @@ loop_fmt :
 				{
 				case 0 :	/* not balanceable, retract */
 					form = t_str;
-					t_str = NIL(char*);
+					t_str = NULL;
 					n_str = 0;
 					goto loop_flags;
 				case LEFTP :	/* increasing nested level */
@@ -248,9 +240,11 @@ loop_fmt :
 						{	if(!fp &&
 							   !(fp = (*_Sffmtposf)(f,oform,oargs,ft,0)) )
 								goto pop_fmt;
-							n = FP_SET(n,argn);
 						}
-						else	n = FP_SET(-1,argn);
+						if(n > xargs)
+							xargs = n;
+						else
+							n=++nargs;
 
 						if(fp)
 						{	t_str = fp[n].argv.s;
@@ -259,9 +253,9 @@ loop_fmt :
 						else if(ft && ft->extf )
 						{	FMTSET(ft, form,args,
 								LEFTP, 0, 0, 0,0,0,
-								NIL(char*),0);
+								NULL,0);
 							n = (*ft->extf)
-							      (f,(void*)&argv,ft);
+							      (f,&argv,ft);
 							if(n < 0)
 								goto pop_fmt;
 							if(!(ft->flags&SFFMT_VALUE) )
@@ -358,15 +352,17 @@ loop_fmt :
 			{	form += 1;
 				if(!fp && !(fp = (*_Sffmtposf)(f,oform,oargs,ft,0)) )
 					goto pop_fmt;
-				n = FP_SET(n,argn);
+				if(n > xargs)
+					xargs = n;
 			}
-			else	n = FP_SET(-1,argn);
+			else
+				n = ++nargs;
 
 			if(fp)
 				v = fp[n].argv.i;
 			else if(ft && ft->extf)
-			{	FMTSET(ft, form,args, '.',dot, 0, 0,0,0, NIL(char*), 0);
-				if((*ft->extf)(f, (void*)(&argv), ft) < 0)
+			{	FMTSET(ft, form,args, '.',dot, 0, 0,0,0, NULL, 0);
+				if((*ft->extf)(f, &argv, ft) < 0)
 					goto pop_fmt;
 				fmt = ft->fmt;
 				flags = (flags&~SFFMT_TYPES) | (ft->flags&SFFMT_TYPES);
@@ -388,6 +384,8 @@ loop_fmt :
 				if(!fp && !(fp = (*_Sffmtposf)(f,oform,oargs,ft,0)) )
 					goto pop_fmt;
 				argp = v-1;
+				if(argp > xargs)
+					xargs = argp;
 				goto loop_flags;
 			}
 		dot_set :
@@ -415,16 +413,19 @@ loop_fmt :
 					if(!fp &&
 					   !(fp = (*_Sffmtposf)(f,oform,oargs,ft,0)))
 						goto pop_fmt;
-					n = FP_SET(n,argn);
+
+					if(n > xargs)
+						xargs = n;
 				}
-				else	n = FP_SET(-1,argn);
+				else
+					n = ++nargs;
 
 				if(fp)	/* use position list */
 					size = fp[n].argv.i;
 				else if(ft && ft->extf)
 				{	FMTSET(ft, form,args, 'I',sizeof(int), 0, 0,0,0,
-						NIL(char*), 0);
-					if((*ft->extf)(f, (void*)(&argv), ft) < 0)
+						NULL, 0);
+					if((*ft->extf)(f, &argv, ft) < 0)
 						goto pop_fmt;
 					if(ft->flags&SFFMT_VALUE)
 						size = argv.i;
@@ -516,18 +517,26 @@ loop_fmt :
 			}
 		}
 
-		argp = FP_SET(argp,argn);
+		if(argp < 0)
+			argp = ++nargs;
 		if(fp)
-		{	if(ft && ft->extf && fp[argp].ft.fmt != fp[argp].fmt)
-				fmt = fp[argp].ft.fmt;
-			argv = fp[argp].argv;
-			size = fp[argp].ft.size;
+		{	if(ft && ft->extf)
+			{	if(fmt == fp[argp].ft.fmt && fp[argp].ft.fmt == fp[argp].fmt)
+				{	argv = fp[argp].argv;
+					size = fp[argp].ft.size;
+				}
+				else	/* reload ft on type mismatch */
+				{	FMTSET(ft, form, args, fmt, size, flags, width, precis, base, t_str, n_str);
+					(*ft->reloadf)(argp, fmt, &argv, ft);
+					FMTGET(ft, form, args, fmt, size, flags, width, precis, base);
+				}
+			}
 		}
 		else if(ft && ft->extf )	/* extended processing */
 		{	FMTSET(ft, form,args, fmt, size,flags, width,precis,base,
 				t_str,n_str);
 			SFEND(f); SFOPEN(f,0);
-			v = (*ft->extf)(f, (void*)(&argv), ft);
+			v = (*ft->extf)(f, &argv, ft);
 			SFLOCK(f,0); SFBUF(f);
 
 			if(v < 0)	/* no further processing */
@@ -621,7 +630,7 @@ loop_fmt :
 				goto pop_fmt;
 			if(!argv.ft->form && ft ) /* change extension functions */
 			{	if(ft->eventf &&
-				   (*ft->eventf)(f,SF_DPOP,(void*)form,ft) < 0)
+				   (*ft->eventf)(f,SFIO_DPOP,(void*)form,ft) < 0)
 					continue;
 				fmstk->ft = ft = argv.ft;
 			}
@@ -641,13 +650,14 @@ loop_fmt :
 					fm->fp = fp;
 
 					form = ft->form; SFMBCLR(ft->mbs);
+					nargs = xargs = -1;
 					va_copy(args,ft->args);
 					argn = -1;
-					fp = NIL(Fmtpos_t*);
+					fp = NULL;
 					oform = (char*)form;
 					va_copy(oargs,args);
 				}
-				else	fm->form = NIL(char*);
+				else	fm->form = NULL;
 
 				fm->eventf = ft->eventf;
 				fm->next = fmstk;
@@ -671,13 +681,11 @@ loop_fmt :
 				{	sp = "(null)";
 					flags &= ~SFFMT_LONG;
 				}
-#if _PACKAGE_ast
 		str_cvt:
 				if(scale)
 				{	size = base = -1;
 					flags &= ~SFFMT_LONG;
 				}
-#endif
 				ls = tls; tls[0] = sp;
 			}
 			for(sp = *ls;;)
@@ -805,6 +813,7 @@ loop_fmt :
 					break;
 				else if(base > 0)
 					{ SFputc(f,base); }
+				nargs++;
 			}
 			continue;
 
@@ -944,12 +953,10 @@ loop_fmt :
 			flags &= ~(SFFMT_SIGN|SFFMT_BLANK);
 			goto int_arg;
 		case 'i':
-#if _PACKAGE_ast
 			if((flags&SFFMT_ALTER) && base < 0)
 			{	flags &= ~SFFMT_ALTER;
 				scale = 1024;
 			}
-#endif
 			fmt = 'd';
 			goto d_format;
 		case 'u':
@@ -957,13 +964,11 @@ loop_fmt :
 			/* FALLTHROUGH */
 		case 'd':
 		d_format:
-#if _PACKAGE_ast
 			if((flags&SFFMT_ALTER) && base < 0)
 			{	flags &= ~SFFMT_ALTER;
 				scale = 1000;
 			}
-#endif
-			if(base < 2 || base > SF_RADIX)
+			if(base < 2 || base > SFIO_RADIX)
 				base = 10;
 			if((base&(n_s = base-1)) == 0)
 			{	if(base < 8)
@@ -985,7 +990,6 @@ loop_fmt :
 					lv = (Sflong_t)argv.l;
 				else	lv = (Sflong_t)argv.ul;
 			long_cvt:
-#if _PACKAGE_ast
 				if(scale)
 				{	sp = fmtscale(lv, scale);
 #if _has_multibyte
@@ -993,7 +997,6 @@ loop_fmt :
 #endif
 					goto str_cvt;
 				}
-#endif
 				if(lv == 0 && precis == 0)
 					break;
 				if(lv < 0 && fmt == 'd' )
@@ -1045,7 +1048,6 @@ loop_fmt :
 			else
 			{	v = argv.i;
 			int_cvt:
-#if _PACKAGE_ast
 				if(scale)
 				{	sp = fmtscale(v, scale);
 #if _has_multibyte
@@ -1053,7 +1055,6 @@ loop_fmt :
 #endif
 					goto str_cvt;
 				}
-#endif
 				if(v == 0 && precis == 0)
 					break;
 				if(v < 0 && fmt == 'd' )
@@ -1159,13 +1160,13 @@ loop_fmt :
 			if(fmt == 'e' || fmt == 'E' && (v |= SFFMT_UPPER))
 			{	v |= SFFMT_EFORMAT;
 				n = (precis = precis < 0 ? FPRECIS : precis)+1;
-				ep = _sfcvt(valp,tmp+1,sizeof(tmp)-1, min(n,SF_FDIGITS),
+				ep = _sfcvt(valp,tmp+1,sizeof(tmp)-1, min(n,SFIO_FDIGITS),
 					    &decpt, &sign, &n_s, v);
 				goto e_format;
 			}
 			else if(fmt == 'f' || fmt == 'F' && (v |= SFFMT_UPPER))
 			{	precis = precis < 0 ? FPRECIS : precis;
-				ep = _sfcvt(valp,tmp+1,sizeof(tmp)-1, min(precis,SF_FDIGITS),
+				ep = _sfcvt(valp,tmp+1,sizeof(tmp)-1, min(precis,SFIO_FDIGITS),
 					    &decpt, &sign, &n_s, v);
 				goto f_format;
 			}
@@ -1177,7 +1178,7 @@ loop_fmt :
 					else	precis = 2*(sizeof(double) - 2);
 				}
 				n = precis + 1;
-				ep = _sfcvt(valp,tmp+1,sizeof(tmp)-1, min(n,SF_FDIGITS),
+				ep = _sfcvt(valp,tmp+1,sizeof(tmp)-1, min(n,SFIO_FDIGITS),
 					    &decpt, &sign, &n_s, v);
 
 				sp = endsp = buf+1;	/* reserve space for sign */
@@ -1194,7 +1195,7 @@ loop_fmt :
 				if(fmt == 'G')
 					v |= SFFMT_UPPER;
 				v |= SFFMT_EFORMAT;
-				ep = _sfcvt(valp,tmp+1,sizeof(tmp)-1, min(precis,SF_FDIGITS),
+				ep = _sfcvt(valp,tmp+1,sizeof(tmp)-1, min(precis,SFIO_FDIGITS),
 					    &decpt, &sign, &n_s, v);
 				if(dval == 0.)
 					decpt = 1;
@@ -1372,15 +1373,20 @@ loop_fmt :
 	}
 
 pop_fmt:
+	if(ft && ft->reloadf) /* fix nargs %.., %5$s i.e. skip argv[] */
+	{	if(xargs > nargs)
+			nargs = xargs;
+		(*ft->reloadf)(nargs+1, 0, NULL, ft);
+	}
 	if(fp)
 	{	free(fp);
-		fp = NIL(Fmtpos_t*);
+		fp = NULL;
 	}
 	while((fm = fmstk) ) /* pop the format stack and continue */
 	{	if(fm->eventf)
 		{	if(!form || !form[0])
-				(*fm->eventf)(f,SF_FINAL,NIL(void*),ft);
-			else if((*fm->eventf)(f,SF_DPOP,(void*)form,ft) < 0)
+				(*fm->eventf)(f,SFIO_FINAL,NULL,ft);
+			else if((*fm->eventf)(f,SFIO_DPOP,(void*)form,ft) < 0)
 				goto loop_fmt;
 		}
 
@@ -1404,7 +1410,7 @@ done:
 		free(fp);
 	while((fm = fmstk) )
 	{	if(fm->eventf)
-			(*fm->eventf)(f,SF_FINAL,NIL(void*),fm->ft);
+			(*fm->eventf)(f,SFIO_FINAL,NULL,fm->ft);
 		fmstk = fm->next;
 		free(fm);
 	}
@@ -1413,12 +1419,12 @@ done:
 
 	n = f->next - f->data;
 	if((sp = (char*)f->data) == data)
-		f->endw = f->endr = f->endb = f->data = NIL(uchar*);
+		f->endw = f->endr = f->endb = f->data = NULL;
 	f->next = f->data;
 
-	if((((flags = f->flags)&SF_SHARE) && !(flags&SF_PUBLIC) ) ||
-	   (n > 0 && (sp == data || (flags&SF_LINE) ) ) )
-		(void)SFWRITE(f,(void*)sp,n);
+	if((((flags = f->flags)&SFIO_SHARE) && !(flags&SFIO_PUBLIC) ) ||
+	   (n > 0 && (sp == data || (flags&SFIO_LINE) ) ) )
+		(void)SFWRITE(f,sp,n);
 	else	f->next += n;
 
 	SFOPEN(f,0);
