@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1985-2011 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2022 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -623,12 +623,12 @@ static Map_t*	maps;
 unsigned char*
 _ccmap(int i, int o)
 {
-	register unsigned char*	a;
-	register unsigned char*	m;
-	register unsigned char*	z;
-	register Map_t*		map;
-	register int		n;
-	int			op;
+	unsigned char*	a;
+	unsigned char*	m;
+	unsigned char*	z;
+	Map_t*		map;
+	int		n;
+	int		op;
 
 	if (!i && !o)
 		return (unsigned char*)tab;
@@ -650,7 +650,7 @@ _ccmap(int i, int o)
 			o = CC_NATIVE;
 	}
 	if (i == o || i < 1 || i > MAPS || o < 1 || o > MAPS)
-		return 0;
+		return NULL;
 	if (i == CC_ASCII)
 		return (unsigned char*)tab + MAP * (2 * (o - 1));
 	if (o == CC_ASCII)
@@ -660,7 +660,7 @@ _ccmap(int i, int o)
 		if (map->op == op)
 			return map->map;
 	if (!(map = newof(0, Map_t, 1, 0)))
-		return 0;
+		return NULL;
 	map->op = op;
 	a = (unsigned char*)tab + MAP * (2 * (o - 1));
 	z = (unsigned char*)tab + MAP * (2 * (i - 1) + 1);
@@ -675,11 +675,11 @@ _ccmap(int i, int o)
 }
 
 void*
-_ccmapcpy(register unsigned char* m, void* b, const void* a, size_t n)
+_ccmapcpy(unsigned char* m, void* b, const void* a, size_t n)
 {
-	register unsigned char*	ub;
-	register unsigned char*	ue;
-	register unsigned char*	ua;
+	unsigned char*	ub;
+	unsigned char*	ue;
+	unsigned char*	ua;
 
 	if (m)
 	{
@@ -695,10 +695,10 @@ _ccmapcpy(register unsigned char* m, void* b, const void* a, size_t n)
 }
 
 void*
-_ccmapstr(register unsigned char* m, void* b, size_t n)
+_ccmapstr(unsigned char* m, void* b, size_t n)
 {
-	register unsigned char*	s;
-	register unsigned char*	e;
+	unsigned char*	s;
+	unsigned char*	e;
 
 	if (m)
 		for (e = (s = (unsigned char*)b) + n; s < e; s++)
@@ -711,9 +711,9 @@ _ccmapstr(register unsigned char* m, void* b, size_t n)
 static void
 dump(int from, int to)
 {
-	register const unsigned char*	m;
-	register int			c;
-	register int			i;
+	const unsigned char*	m;
+	int			c;
+	int			i;
 
 	m = ccmap(from, to);
 	sfprintf(sfstdout, "\n /* %s => %s */\n\n", ccmapname(from), ccmapname(to));
@@ -728,9 +728,10 @@ dump(int from, int to)
 	}
 }
 
+int
 main(int argc, char** argv)
 {
-	register int			i;
+	int			i;
 
 	for (i = 1; i <= CC_MAPS; i++)
 	{
