@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1992-2012 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2022 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2024 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -227,14 +227,12 @@ preserve(State_t* state, const char* path, struct stat* ns, struct stat* os)
  */
 
 static int
-visit(State_t* state, register FTSENT* ent)
+visit(State_t* state, FTSENT* ent)
 {
-	register char*	base;
-	register int	n;
-	register int	len;
-	int		rm;
-	int		rfd;
-	int		wfd;
+	char*		base;
+	int		n;
+	int		len;
+	int		rm = state->remove || ent->fts_info == FTS_SL;
 	int		m;
 	int		v;
 	char*		s;
@@ -249,7 +247,7 @@ visit(State_t* state, register FTSENT* ent)
 	if (ent->fts_info == FTS_DC)
 	{
 		error(2, "%s: directory causes cycle", ent->fts_path);
-		fts_set(NiL, ent, FTS_SKIP);
+		fts_set(NULL, ent, FTS_SKIP);
 		return 0;
 	}
 	if (ent->fts_level == 0)
@@ -309,7 +307,7 @@ visit(State_t* state, register FTSENT* ent)
 					if (mkdir(state->path, st.st_mode & S_IPERM))
 					{
 						error(ERROR_SYSTEM|2, "%s: cannot create directory -- %s ignored", state->path, ent->fts_path);
-						fts_set(NiL, ent, FTS_SKIP);
+						fts_set(NULL, ent, FTS_SKIP);
 						return 0;
 					}
 				}
@@ -343,7 +341,7 @@ visit(State_t* state, register FTSENT* ent)
 	case FTS_D:
 		if (!state->recursive)
 		{
-			fts_set(NiL, ent, FTS_SKIP);
+			fts_set(NULL, ent, FTS_SKIP);
 			if (state->op == CP)
 				error(1, "%s: directory -- copying as plain file", ent->fts_path);
 			else if (state->link == link && !state->force)
@@ -359,7 +357,7 @@ visit(State_t* state, register FTSENT* ent)
 			return 0;
 		case FTS_DNX:
 			error(2, "%s: cannot search directory", ent->fts_path);
-			fts_set(NiL, ent, FTS_SKIP);
+			fts_set(NULL, ent, FTS_SKIP);
 
 			/* FALLTHROUGH */
 		case FTS_D:
@@ -376,7 +374,7 @@ visit(State_t* state, register FTSENT* ent)
 			else if (mkdir(state->path, (ent->fts_statp->st_mode & S_IPERM)|(ent->fts_info == FTS_D ? S_IRWXU : 0)))
 			{
 				error(ERROR_SYSTEM|2, "%s: cannot create directory -- %s ignored", state->path, ent->fts_path);
-				fts_set(NiL, ent, FTS_SKIP);
+				fts_set(NULL, ent, FTS_SKIP);
 			}
 			if (!state->directory)
 			{
@@ -403,7 +401,7 @@ visit(State_t* state, register FTSENT* ent)
 		st.st_mode = 0;
 	else if (state->update && !S_ISDIR(st.st_mode) && (unsigned long)ent->fts_statp->st_mtime < (unsigned long)st.st_mtime)
 	{
-		fts_set(NiL, ent, FTS_SKIP);
+		fts_set(NULL, ent, FTS_SKIP);
 		return 0;
 	}
 	else
@@ -430,7 +428,6 @@ visit(State_t* state, register FTSENT* ent)
 		}
 		if (state->verbose)
 			sfputr(sfstdout, state->path, '\n');
-		rm = state->remove || ent->fts_info == FTS_SL;
 		if (!rm || !state->force)
 		{
 			if (S_ISLNK(st.st_mode) && (n = -1) || (n = open(state->path, O_RDWR|O_BINARY|O_cloexec)) >= 0)
@@ -493,14 +490,14 @@ visit(State_t* state, register FTSENT* ent)
 				s = state->path;
 			}
 			n = strlen(s);
-			if (fts = fts_open((char**)e, FTS_NOCHDIR|FTS_ONEPATH|FTS_PHYSICAL|FTS_NOPOSTORDER|FTS_NOSTAT|FTS_NOSEEDOTDIR, NiL))
+			if (fts = fts_open((char**)e, FTS_NOCHDIR|FTS_ONEPATH|FTS_PHYSICAL|FTS_NOPOSTORDER|FTS_NOSTAT|FTS_NOSEEDOTDIR, NULL))
 			{
 				while (sub = fts_read(fts))
 				{
 					if (strneq(s, sub->fts_name, n) && sub->fts_name[n] == '.' && strneq(sub->fts_name + n + 1, state->suffix, state->suflen) && (m = strtol(sub->fts_name + n + state->suflen + 1, &e, 10)) && streq(e, state->suffix) && m > v)
 						v = m;
 					if (sub->fts_level)
-						fts_set(NiL, sub, FTS_SKIP);
+						fts_set(NULL, sub, FTS_SKIP);
 				}
 				fts_close(fts);
 			}
@@ -576,6 +573,8 @@ visit(State_t* state, register FTSENT* ent)
 		}
 		else if (state->op == CP || S_ISREG(ent->fts_statp->st_mode) || S_ISDIR(ent->fts_statp->st_mode))
 		{
+			int	rfd = -1;
+			int	wfd = -1;
 			if (ent->fts_statp->st_size > 0 && (rfd = open(ent->fts_path, O_RDONLY|O_BINARY|O_cloexec)) < 0)
 			{
 				error(ERROR_SYSTEM|2, "%s: cannot read", ent->fts_path);
@@ -590,14 +589,14 @@ visit(State_t* state, register FTSENT* ent)
 			}
 			else if (ent->fts_statp->st_size > 0)
 			{
-				if (!(ip = sfnew(NiL, NiL, SF_UNBOUND, rfd, SF_READ)))
+				if (!(ip = sfnew(NULL, NULL, SFIO_UNBOUND, rfd, SFIO_READ)))
 				{
 					error(ERROR_SYSTEM|2, "%s: %s read stream error", ent->fts_path, state->path);
 					close(rfd);
 					close(wfd);
 					return 0;
 				}
-				if (!(op = sfnew(NiL, NiL, SF_UNBOUND, wfd, SF_WRITE)))
+				if (!(op = sfnew(NULL, NULL, SFIO_UNBOUND, wfd, SFIO_WRITE)))
 				{
 					error(ERROR_SYSTEM|2, "%s: %s write stream error", ent->fts_path, state->path);
 					close(wfd);
@@ -605,7 +604,7 @@ visit(State_t* state, register FTSENT* ent)
 					return 0;
 				}
 				n = 0;
-				if (sfmove(ip, op, (Sfoff_t)SF_UNBOUND, -1) < 0)
+				if (sfmove(ip, op, (Sfoff_t)SFIO_UNBOUND, -1) < 0)
 					n |= 3;
 				if (!sfeof(ip))
 					n |= 1;
@@ -662,16 +661,16 @@ visit(State_t* state, register FTSENT* ent)
 }
 
 int
-b_cp(int argc, register char** argv, Shbltin_t* context)
+b_cp(int argc, char** argv, Shbltin_t* context)
 {
-	register char*	file;
-	register char*	s;
+	char*		file;
+	char*		s;
 	char**		v;
 	char*		backup_type;
 	FTS*		fts;
 	FTSENT*		ent;
 	const char*	usage;
-	int		path_resolve;
+	int		path_resolve = 0;
 	int		standard;
 	struct stat	st;
 	State_t*	state;
@@ -873,7 +872,7 @@ b_cp(int argc, register char** argv, Shbltin_t* context)
 		argc--;
 		argv++;
 	}
-	if (!(v = (char**)stkalloc(stkstd, (argc + 2) * sizeof(char*))))
+	if (!(v = stkalloc(stkstd, (argc + 2) * sizeof(char*))))
 	{
 		error(ERROR_SYSTEM|ERROR_PANIC, "out of memory");
 		UNREACHABLE();
@@ -945,7 +944,7 @@ b_cp(int argc, register char** argv, Shbltin_t* context)
 	}
 	if (argc <= 0 || error_info.errors)
 	{
-		error(ERROR_usage(2), "%s", optusage(NiL));
+		error(ERROR_usage(2), "%s", optusage(NULL));
 		UNREACHABLE();
 	}
 	if (!path_resolve)
@@ -963,7 +962,7 @@ b_cp(int argc, register char** argv, Shbltin_t* context)
 		pathcanon(file, 0, 0);
 	if (!(state->directory = !stat(file, &st) && S_ISDIR(st.st_mode)) && argc > 1)
 	{
-		error(ERROR_usage(2), "%s", optusage(NiL));
+		error(ERROR_usage(2), "%s", optusage(NULL));
 		UNREACHABLE();
 	}
 	if (s && !state->directory)
@@ -986,7 +985,7 @@ b_cp(int argc, register char** argv, Shbltin_t* context)
 	state->perm = state->uid ? S_IPERM : (S_IPERM & ~S_ISVTX);
 	if (!state->recursive)
 		state->flags |= FTS_TOP;
-	if (fts = fts_open(argv, state->flags, NiL))
+	if (fts = fts_open(argv, state->flags, NULL))
 	{
 		while (!sh_checksig(context) && (ent = fts_read(fts)) && !visit(state, ent));
 		fts_close(fts);
