@@ -2,7 +2,7 @@
 *                                                                      *
 *               This software is part of the ast package               *
 *          Copyright (c) 1997-2012 AT&T Intellectual Property          *
-*          Copyright (c) 2020-2023 Contributors to ksh 93u+m           *
+*          Copyright (c) 2020-2024 Contributors to ksh 93u+m           *
 *                      and is licensed under the                       *
 *                 Eclipse Public License, Version 2.0                  *
 *                                                                      *
@@ -29,7 +29,6 @@
 	Dllent_t	entry; \
 	Uniq_t*		uniq; \
 	int		flags; \
-	Vmalloc_t*	vm; \
 	Dt_t*		dict; \
 	Dtdisc_t	disc; \
 	FTS*		fts; \
@@ -57,7 +56,6 @@
 #include <ctype.h>
 #include <error.h>
 #include <fts.h>
-#include <vmalloc.h>
 
 typedef struct Uniq_s
 {
@@ -103,7 +101,8 @@ dllinfo(void)
 				s++;
 			if (*s)
 			{
-				h = 0;
+				h = NULL;
+				vn = 0;
 				for (;;)
 				{
 					for (d = s; *s && *s != ':' && *s != ','; s++);
@@ -145,6 +144,8 @@ dllinfo(void)
 				}
 				if (v && vn < sizeof(info.envbuf))
 				{
+					if(vn <= 0)
+						abort();
 					memcpy(info.envbuf, v, vn);
 					info.env = info.envbuf;
 				}
@@ -212,14 +213,11 @@ dllsopen(const char* lib, const char* name, const char* version)
 	char*		t;
 	Dllscan_t*	scan;
 	Dllinfo_t*	info;
-	Vmalloc_t*	vm;
 	int		i;
 	int		j;
 	int		k;
 	char		buf[32];
 
-	if (!(vm = vmopen(Vmdcheap, Vmlast, 0)))
-		return NULL;
 	if (lib && *lib && (*lib != '-' || *(lib + 1)))
 	{
 		/*
@@ -237,12 +235,8 @@ dllsopen(const char* lib, const char* name, const char* version)
 	}
 	if (version && (!*version || *version == '-' && !*(version + 1)))
 		version = 0;
-	if (!(scan = vmnewof(vm, 0, Dllscan_t, 1, i)) || !(scan->tmp = sfstropen()))
-	{
-		vmclose(vm);
+	if (!(scan = calloc(1, sizeof(Dllscan_t) + i)) || !(scan->tmp = sfstropen()))
 		return NULL;
-	}
-	scan->vm = vm;
 	info = dllinfo();
 	scan->flags = info->flags;
 	if (lib)
@@ -260,7 +254,7 @@ dllsopen(const char* lib, const char* name, const char* version)
 	}
 	else if (t = strrchr(name, '/'))
 	{
-		if (!(scan->pb = vmnewof(vm, 0, char, t - (char*)name, 2)))
+		if (!(scan->pb = calloc(1, t - (char*)name + 2)))
 			goto bad;
 		memcpy(scan->pb, name, t - (char*)name);
 		name = (const char*)(t + 1);
@@ -275,7 +269,7 @@ dllsopen(const char* lib, const char* name, const char* version)
 			if (i > k && streq(name + i - k, info->suffix))
 			{
 				i -= j + k;
-				if (!(t = vmnewof(vm, 0, char, i, 1)))
+				if (!(t = calloc(1, i + 1)))
 					goto bad;
 				memcpy(t, name + j, i);
 				t[i] = 0;
@@ -289,7 +283,7 @@ dllsopen(const char* lib, const char* name, const char* version)
 					if (*t != '-')
 						scan->flags |= DLL_MATCH_VERSION;
 					version = t + 1;
-					if (!(s = vmnewof(vm, 0, char, t - (char*)name, 1)))
+					if (!(s = calloc(1, t - (char*)name + 1)))
 						goto bad;
 					memcpy(s, name, t - (char*)name);
 					name = (const char*)s;
@@ -363,8 +357,6 @@ dllsclose(Dllscan_t* scan)
 		dtclose(scan->dict);
 	if (scan->tmp)
 		sfclose(scan->tmp);
-	if (scan->vm)
-		vmclose(scan->vm);
 	return 0;
 }
 
@@ -505,14 +497,14 @@ dllsread(Dllscan_t* scan)
 		}
 		if (dtmatch(scan->dict, b))
 			goto again;
-		if (!(u = vmnewof(scan->vm, 0, Uniq_t, 1, strlen(b))))
+		if (!(u = calloc(1, sizeof(Uniq_t) + strlen(b))))
 			return NULL;
 		strcpy(u->name, b);
 		dtinsert(scan->dict, u);
 	}
 	else if (!(scan->flags & DLL_MATCH_NAME))
 		scan->flags |= DLL_MATCH_DONE;
-	else if (!(scan->uniq = vmnewof(scan->vm, 0, Uniq_t, 1, strlen(b))))
+	else if (!(scan->uniq = calloc(1, sizeof(Uniq_t) + strlen(b))))
 		return NULL;
 	else
 		strcpy(scan->uniq->name, b);
